@@ -67,16 +67,20 @@ namespace
 
 }
 
-DataImpl :: DataImpl (const StringView& cache_ext, bool unit_test, int cache_megs, DataIO * io):
+DataImpl :: DataImpl (const StringView& cache_ext, Prefs& prefs, bool unit_test, int cache_megs, DataIO * io):
   ProfilesImpl (*io),
   _cache (get_cache_path(), cache_ext, cache_megs),
+  _prefs(prefs),
   _encode_cache (get_encode_cache_path(), cache_megs),
   _certstore(*this),
   _unit_test (unit_test),
   _data_io (io),
   _descriptions_loaded (false),
   newsrc_autosave_id (0),
-  newsrc_autosave_timeout (0)
+  newsrc_autosave_timeout (0),
+  _rules_filter (prefs.get_flag("rules-autocache-mark-read", false),
+                 prefs.get_flag("rules-auto-dl-mark-read", false),
+                 prefs.get_flag("rules-autocache-mark-read", false))
 
 {
   rebuild_backend ();
@@ -113,7 +117,6 @@ DataImpl :: rebuild_backend ()
 DataImpl :: ~DataImpl ()
 {
   save_state ();
-
 }
 
 void
@@ -166,9 +169,11 @@ DataImpl :: password_decrypt (PasswordData& pw) const
     pw.pw = gnome_keyring_memory_strdup(pwd);
     gnome_keyring_free_password(pwd);
   }
+  else
+  {
+    pw.pw = const_cast<gchar*>("");
+  }
 
   return (pw.pw ? GNOME_KEYRING_RESULT_OK : GNOME_KEYRING_RESULT_DENIED) ;
 }
 #endif
-
-
