@@ -81,7 +81,15 @@ namespace
   }
 }
 
+// detect std::lib
+#include <ciso646>
+#ifdef _LIBCPP_VERSION
+// using libc++
+#include <algorithm>
+#else
+// using libstdc++
 #include <ext/algorithm>
+#endif
 
 void
 DataImpl :: load_newsrc (const Quark       & server,
@@ -116,7 +124,7 @@ DataImpl :: load_newsrc (const Quark       & server,
 
       if (subscribed)
         tmp_sub.push_back (group);
-      else 
+      else
         tmp_unsub.push_back (group);
 
       if (!numbers.empty())
@@ -155,20 +163,6 @@ DataImpl :: load_newsrc (const Quark       & server,
   }
 }
 
-namespace {
-  inline std::string newsrc_fn(const std::string &base)
-  {
-    const char *fn = base.c_str();
-    if (g_path_is_absolute(fn))
-      return base;
-    const char *ph = file::get_pan_home().c_str();
-    char *temp = g_build_filename(ph, fn, NULL);
-    std::string out(temp);
-    g_free(temp);
-    return out;
-  }
-}
-
 void
 DataImpl :: load_newsrc_files (const DataIO& data_io)
 {
@@ -180,7 +174,7 @@ DataImpl :: load_newsrc_files (const DataIO& data_io)
 
   foreach_const (servers_t, _servers, sit) {
     const Quark key (sit->first);
-    const std::string filename = newsrc_fn (sit->second.newsrc_filename);
+    const std::string filename = file::absolute_fn("", sit->second.newsrc_filename);
     if (file::file_exists (filename.c_str())) {
       LineReader * in (data_io.read_file (filename));
       load_newsrc (key, in, s, u);
@@ -189,8 +183,8 @@ DataImpl :: load_newsrc_files (const DataIO& data_io)
   }
 
   // remove duplicates
-  s.erase (std::unique(s.begin(), s.end()), s.end()); 
-  u.erase (std::unique(u.begin(), u.end()), u.end()); 
+  s.erase (std::unique(s.begin(), s.end()), s.end());
+  u.erase (std::unique(u.begin(), u.end()), u.end());
 
   // unsub -= sub
   AlphabeticalQuarkOrdering o;
@@ -208,14 +202,16 @@ DataImpl :: load_newsrc_files (const DataIO& data_io)
 void
 DataImpl :: save_newsrc_files (DataIO& data_io) const
 {
-  if (!in_newsrc_cb && newsrc_autosave_id)
+  if (newsrc_autosave_id) {
     g_source_remove( newsrc_autosave_id );
+    newsrc_autosave_id = 0;
+  }
 
   if (_unit_test)
     return;
 
   // overly-complex optimization: both sit->second.groups and _subscribed
-  // are both ordered by AlphabeticalQuarkOrdering.  
+  // are both ordered by AlphabeticalQuarkOrdering.
   // Where N==sit->second.groups.size() and M==_subscribed.size(),
   // "bool subscribed = _subscribed.count (group)" is N*log(M),
   // but a sorted set comparison is M+N comparisons.
@@ -227,7 +223,8 @@ DataImpl :: save_newsrc_files (DataIO& data_io) const
     const Quark& server (sit->first);
 
     // write this server's newsrc
-    const std::string filename = newsrc_fn (sit->second.newsrc_filename);
+    const std::string filename = file::absolute_fn("", sit->second.newsrc_filename);
+
     std::ostream& out (*data_io.write_file (filename));
     std::string newsrc_string;
     alpha_groups_t::const_iterator sub_it (_subscribed.begin());
@@ -290,11 +287,11 @@ DataImpl :: load_group_permissions (const DataIO& data_io)
   }
 
   std::sort (m.begin(), m.end());
-  m.erase (std::unique(m.begin(), m.end()), m.end()); 
+  m.erase (std::unique(m.begin(), m.end()), m.end());
   _moderated.get_container().swap (m);
 
   std::sort (n.begin(), n.end());
-  n.erase (std::unique(n.begin(), n.end()), n.end()); 
+  n.erase (std::unique(n.begin(), n.end()), n.end());
   _nopost.get_container().swap (n);
 
   delete in;
@@ -312,7 +309,7 @@ DataImpl :: save_group_permissions (DataIO& data_io) const
   tmp_t tmp;
   foreach_const (groups_t, _moderated, it) tmp[*it] = 'm';
   foreach_const (groups_t, _nopost, it) tmp[*it] = 'n';
-  
+
   out << "# Permissions: y means posting ok; n means posting not okay; m means moderated.\n"
       << "# Since almost all groups allow posting, Pan assumes that as the default.\n"
       << "# Only moderated or no-posting groups are listed here.\n";
@@ -369,7 +366,7 @@ DataImpl :: load_group_xovers (const DataIO& data_io)
       line.trim();
       if (line.empty() || *line.str=='#')
         continue;
-     
+
       if (line.pop_token(groupname) && line.pop_token(total) && line.pop_token(unread))
       {
         ReadGroup& g (_read_groups[groupname]);
@@ -485,7 +482,7 @@ DataImpl :: get_xover_high (const Quark  & groupname,
     high = rgs->_xover_high;
   return high;
 }
-                                                                                
+
 void
 DataImpl :: set_xover_high (const Quark & group,
                             const Quark & server,
@@ -520,7 +517,7 @@ DataImpl :: add_groups (const Quark       & server,
     std::set_union (s->groups.begin(), s->groups.end(),
                     groups.begin(), groups.end(),
                     std::back_inserter (tmp), o);
-    tmp.erase (std::unique(tmp.begin(), tmp.end()), tmp.end()); 
+    tmp.erase (std::unique(tmp.begin(), tmp.end()), tmp.end());
     s->groups.get_container().swap (tmp);
 
     // make a groups_t of groups we didn't already have,
@@ -534,12 +531,12 @@ DataImpl :: add_groups (const Quark       & server,
     std::set_union (groups.begin(), groups.end(),
                     _unsubscribed.begin(), _unsubscribed.end(),
                     std::back_inserter (tmp), o);
-    tmp.erase (std::unique(tmp.begin(), tmp.end()), tmp.end()); 
+    tmp.erase (std::unique(tmp.begin(), tmp.end()), tmp.end());
     _unsubscribed.get_container().swap (tmp);
   }
 
   {
-    // build lists of the groups that should and should not be in _moderated and _nopost.
+    // build lists of the groups that should and should not be in _moderated and _nopost.t
     // this is pretty cumbersome, but since these lists almost never change it's still
     // a worthwhile tradeoff to get the speed/memory wins of a sorted_vector
     groups_t mod, notmod, post, nopost, tmp;
@@ -565,7 +562,7 @@ DataImpl :: add_groups (const Quark       & server,
     tmp.clear ();
     std::set_difference (_nopost.begin(), _nopost.end(), post.begin(), post.end(), inserter (tmp, tmp.begin()));
     _nopost.swap (tmp);
-    // _nopost += nopost 
+    // _nopost += nopost
     tmp.clear ();
     std::set_union (_nopost.begin(), _nopost.end(), nopost.begin(), nopost.end(), inserter (tmp, tmp.begin()));
     _nopost.swap (tmp);
@@ -666,11 +663,11 @@ DataImpl :: server_get_groups (const Quark& servername, quarks_t& addme) const
 void
 DataImpl :: get_subscribed_groups (std::vector<Quark>& setme) const
 {
-  setme.assign (_subscribed.begin(), _subscribed.end()); 
+  setme.assign (_subscribed.begin(), _subscribed.end());
 }
 
 void
 DataImpl :: get_other_groups (std::vector<Quark>& setme) const
 {
-  setme.assign (_unsubscribed.begin(), _unsubscribed.end()); 
+  setme.assign (_unsubscribed.begin(), _unsubscribed.end());
 }
