@@ -213,10 +213,11 @@ DataImpl :: MyTree :: apply_rules (const_nodes_v& candidates)
   //  maybe include threads or subthreads...
   if (_show_type == Data::SHOW_THREADS)
   {
-    foreach (const_nodes_v, pass, it) {
-      const ArticleNode *& n (*it);
-      while (n->_parent)
-        n = n->_parent;
+    const_nodes_v passcopy=pass;
+    foreach (const_nodes_v, passcopy, it) {
+      const ArticleNode *n (*it);
+      while ((n = n->_parent))
+        pass.push_back(n);
     }
     std::sort (pass.begin(), pass.end(), compare);
     pass.erase (std::unique (pass.begin(), pass.end()), pass.end());
@@ -251,32 +252,38 @@ DataImpl :: MyTree :: apply_rules (const_nodes_v& candidates)
 void
 DataImpl :: MyTree :: cache_articles (std::set<const Article*> s)
 {
-  Queue * q (_data.get_queue());
-  if (!q) return;
+  Queue* queue (_data.get_queue());
+  Prefs& prefs (_data.get_prefs());
+  const bool action (prefs.get_flag("rules-autocache-mark-read", false));
 
   Queue::tasks_t tasks;
   ArticleCache& cache(_data.get_cache());
   foreach_const (std::set<const Article*>, s, it)
     if (!_data.is_read(*it))
-      tasks.push_back (new TaskArticle (_data, _data, **it, cache, _data));
+      tasks.push_back (new TaskArticle (_data, _data, **it, cache, _data,
+                                        action ? TaskArticle::ACTION_TRUE : TaskArticle::ACTION_FALSE));
   if (!tasks.empty())
-    q->add_tasks (tasks, Queue::BOTTOM);
+    queue->add_tasks (tasks, Queue::BOTTOM);
 }
 
 void
 DataImpl :: MyTree :: download_articles (std::set<const Article*> s)
 {
-  Queue * q (_data.get_queue());
-  if (!q) return;
+  Queue* queue (_data.get_queue());
 
   Queue::tasks_t tasks;
   ArticleCache& cache(_data.get_cache());
+  Prefs& prefs (_data.get_prefs());
+  const bool action (prefs.get_flag("rules-auto-dl-mark-read", false));
+  const bool always (prefs.get_flag("mark-downloaded-articles-read", false));
 
   foreach_const (std::set<const Article*>, s, it)
     if (!_data.is_read(*it))
-      tasks.push_back (new TaskArticle (_data, _data, **it, cache, _data, 0, TaskArticle::DECODE, _save_path));
+      tasks.push_back (new TaskArticle (_data, _data, **it, cache, _data,
+                                        always ? TaskArticle::ALWAYS_MARK : action ? TaskArticle::ACTION_TRUE : TaskArticle::ACTION_FALSE,
+                                        0, TaskArticle::DECODE, _save_path));
   if (!tasks.empty())
-    q->add_tasks (tasks, Queue::BOTTOM);
+    queue->add_tasks (tasks, Queue::BOTTOM);
 }
 
 
