@@ -27,6 +27,7 @@
 
 #include <pan/general/macros.h>
 #include <pan/general/quark.h>
+#include <pan/general/compression.h>
 #include <pan/general/string-view.h>
 #include <pan/usenet-utils/scorefile.h>
 #include <pan/data/article.h>
@@ -35,6 +36,8 @@
 #include <pan/data/cert-store.h>
 #include <pan/data/server-info.h>
 
+#include <pan/gui/prefs.h>
+#include <pan/gui/progress-view.h>
 
 #ifdef HAVE_GKR
   #include <gnome-keyring-1/gnome-keyring.h>
@@ -178,7 +181,6 @@ namespace pan
       {
         Quark server;
         StringView user;
-//        StringView pw;
         gchar* pw;
       };
 
@@ -196,12 +198,13 @@ namespace pan
          int rank;
          int ssl_support;
          int trust;
+         int compression_type;
          typedef sorted_vector<Quark,true,AlphabeticalQuarkOrdering> groups_t;
          groups_t groups;
          gchar* gkr_pw;
 
          Server(): port(STD_NNTP_PORT), article_expiration_age(31), max_connections(2),
-                    rank(1), ssl_support(0), trust(0), gkr_pw(NULL) {}
+                    rank(1), ssl_support(0), trust(0), gkr_pw(NULL), compression_type(0) /* NONE */ {}
       };
 
     protected:
@@ -268,6 +271,8 @@ namespace pan
 
       virtual bool get_server_trust (const Quark  & servername, int&) const = 0;
 
+      virtual bool get_server_compression_type (const Quark  & servername, CompressionType&) const = 0;
+
       virtual std::string get_server_cert (const Quark & server) const = 0;
 
       virtual int get_server_limits (const Quark & server) const = 0;
@@ -590,16 +595,10 @@ namespace pan
 
        virtual void rescore_articles (const Quark& group, const quarks_t mids) = 0;
 
+       virtual void rescore_group_articles (const Quark& group) = 0;
+
        virtual void rescore () = 0;
 
-    public:
-      void set_queue (Queue* q) { _queue = q; }
-      Queue* get_queue () { return _queue; }
-
-    private:
-      Queue * _queue;
-
-
     /*****************************************************************
     ***
     ***  HEADERS - XOVER
@@ -640,7 +639,8 @@ namespace pan
                                          const StringView     & references,
                                          const unsigned long    byte_count,
                                          const unsigned long    line_count,
-                                         const StringView     & xref) = 0;
+                                         const StringView     & xref,
+                                         const bool             is_virtual=false) = 0;
 
       /**
        * The last call to xover_unref() for a group can indicate to Data
@@ -676,6 +676,9 @@ namespace pan
                                    const Quark         & server,
                                    const uint64_t   low) = 0;
 
+      /** Sets the queue interface */
+      virtual void set_queue (Queue* q) = 0;
+
   };
 }
 
