@@ -22,10 +22,12 @@
 
 #include <string>
 #include <pan/general/quark.h>
+#include <pan/general/compression.h>
 #include <pan/general/string-view.h>
 
 namespace pan
 {
+
   struct ServerRank
   {
     virtual ~ServerRank () {}
@@ -38,6 +40,7 @@ namespace pan
    */
   class ServerInfo: public ServerRank
   {
+
     public:
 
       virtual ~ServerInfo () {}
@@ -52,6 +55,9 @@ namespace pan
       virtual void set_server_trust (const Quark       & servername,
                                      const int           setme) = 0;
 
+      virtual void set_server_compression_type (const Quark       & servername,
+                                                  const int           setme) = 0;
+
       virtual void set_server_addr (const Quark       & servername,
                                     const StringView  & address,
                                     const int           port) = 0;
@@ -81,6 +87,8 @@ namespace pan
 
       virtual bool get_server_trust (const Quark  & servername, int&) const = 0;
 
+      virtual bool get_server_compression_type (const Quark  & servername, CompressionType&) const = 0;
+
       virtual bool get_server_addr (const Quark   & servername,
                                     std::string   & setme_address,
                                     int           & setme_port) const = 0;
