@@ -61,6 +61,7 @@ namespace pan
     { icon_filter_only_attachments, "ICON_ONLY_ATTACHMENTS" },
     { icon_filter_only_cached, "ICON_ONLY_CACHED" },
     { icon_filter_only_me, "ICON_ONLY_ME" },
+    { icon_filter_only_read, "ICON_ONLY_READ" },
     { icon_filter_only_unread, "ICON_ONLY_UNREAD" },
     { icon_filter_only_watched, "ICON_ONLY_WATCHED" },
     { icon_get_dialog, "ICON_GET_DIALOG" },
@@ -74,7 +75,11 @@ namespace pan
     { icon_score, "ICON_SCORE" },
     { icon_search_pulldown, "ICON_SEARCH_PULLDOWN" },
     { icon_red_flag, "ICON_FLAGGED"},
-    { icon_get_flagged, "ICON_GET_FLAGGED" }
+    { icon_get_flagged, "ICON_GET_FLAGGED" },
+    { icon_expand_thread, "ICON_EXPAND_THREAD" },
+    { icon_collapse_thread, "ICON_COLLAPSE_THREAD" },
+    { icon_show_signature, "ICON_SHOW_SIGNATURE" }
+
   };
 
   void
@@ -152,6 +157,8 @@ namespace pan
   void do_read_parent_article          (GtkAction*) { pan_ui->do_read_parent_article(); }
   void do_show_servers_dialog          (GtkAction*) { pan_ui->do_show_servers_dialog(); }
   void do_show_sec_dialog              (GtkAction*) { pan_ui->do_show_sec_dialog(); }
+  void do_collapse_thread              (GtkAction*) { pan_ui->do_collapse_thread(); }
+  void do_expand_thread                (GtkAction*) { pan_ui->do_expand_thread(); }
   void do_plonk                        (GtkAction*) { pan_ui->do_plonk(); }
   void do_ignore                       (GtkAction*) { pan_ui->do_ignore(); }
   void do_watch                        (GtkAction*) { pan_ui->do_watch(); }
@@ -180,7 +187,7 @@ namespace pan
   void do_about_pan                    (GtkAction*) { pan_ui->do_about_pan(); }
 
   void do_work_online         (GtkToggleAction * a) { pan_ui->do_work_online         (gtk_toggle_action_get_active(a)); }
-  void do_tabbed_layout       (GtkToggleAction * a) { pan_ui->do_tabbed_layout       (gtk_toggle_action_get_active(a)); }
+  void do_layout              (GtkToggleAction * a) { pan_ui->do_layout              (gtk_toggle_action_get_active(a)); }
   void do_show_group_pane     (GtkToggleAction * a) { pan_ui->do_show_group_pane     (gtk_toggle_action_get_active(a)); }
   void do_show_header_pane    (GtkToggleAction * a) { pan_ui->do_show_header_pane    (gtk_toggle_action_get_active(a)); }
   void do_show_body_pane      (GtkToggleAction * a) { pan_ui->do_show_body_pane      (gtk_toggle_action_get_active(a)); }
@@ -252,6 +259,15 @@ namespace pan
     pan_ui->do_enable_toggle_rules(prefs->_rules_enabled);
   }
 
+  void do_toggle_expand_thread (GtkToggleAction * a)
+  {
+    const bool active (gtk_toggle_action_get_active (a));
+    if (active)
+      do_expand_thread(NULL);
+    else
+      do_collapse_thread(NULL);
+  }
+
   void do_match_only_watched_articles (GtkToggleAction * a)   { set_new_match_on_score_state (gtk_toggle_action_get_active(a) ? MATCH_WATCHED : prev_score_state); }
   void do_match_watched_articles (GtkToggleAction * a)        { set_score_state_bit_from_toggle (a, MATCH_WATCHED); }
   void do_match_high_scoring_articles (GtkToggleAction * a)   { set_score_state_bit_from_toggle (a, MATCH_HIGH_SCORING); }
@@ -267,7 +283,20 @@ namespace pan
   void do_match_only_cached_articles (GtkToggleAction * a) { pan_ui->do_match_only_cached_articles (gtk_toggle_action_get_active(a)); }
   void do_match_only_binary_articles (GtkToggleAction * a) { pan_ui->do_match_only_binary_articles (gtk_toggle_action_get_active(a)); }
   void do_match_only_my_articles (GtkToggleAction * a) { pan_ui->do_match_only_my_articles (gtk_toggle_action_get_active(a)); }
-  void do_match_only_unread_articles (GtkToggleAction * a) { pan_ui->do_match_only_unread_articles (gtk_toggle_action_get_active(a)); }
+  void do_match_only_unread_articles (GtkToggleAction * a)
+  {
+    const bool active (gtk_toggle_action_get_active(a));
+    toggle_action_set_active("match-only-unread-articles", active);
+    if (active) toggle_action_set_active("match-only-read-articles", false);
+    pan_ui->do_match_only_unread_articles(true);
+  }
+  void do_match_only_read_articles (GtkToggleAction * a)
+  {
+    const bool active (gtk_toggle_action_get_active(a));
+    toggle_action_set_active("match-only-read-articles", active);
+    if (active) toggle_action_set_active("match-only-unread-articles", false);
+    pan_ui->do_match_only_read_articles(true);
+  }
 
     GtkActionEntry entries[] =
     {
@@ -670,7 +699,8 @@ namespace pan
       { "show-sec-dialog", GTK_STOCK_DIALOG_AUTHENTICATION,
         N_("Edit _SSL Certificates"), NULL,
         NULL,
-        G_CALLBACK(do_show_sec_dialog) } };
+        G_CALLBACK(do_show_sec_dialog) }
+     };
 
   void prefs_toggle_callback_impl (GtkToggleAction * action)
   {
@@ -684,7 +714,7 @@ namespace pan
   {
     { "thread-headers",           NULL, N_("_Thread Headers"),                NULL, NULL, G_CALLBACK(prefs_toggle_callback_impl), true },
     { "wrap-article-body",GTK_STOCK_JUSTIFY_FILL, N_("Wrap Article Body"),    "W", NULL, G_CALLBACK(prefs_toggle_callback_impl), false },
-    { "show-article-sig",GTK_STOCK_EDIT, N_("Show Article Signature"),        "I", NULL, G_CALLBACK(prefs_toggle_callback_impl), false },
+    { "show-article-sig", "ICON_SHOW_SIGNATURE", N_("Show Article Signature"),"I", NULL, G_CALLBACK(prefs_toggle_callback_impl), false },
     { "mute-quoted-text",         NULL, N_("Mute _Quoted Text"),              "Q", NULL, G_CALLBACK(prefs_toggle_callback_impl), true },
     { "show-all-headers",         NULL, N_("Show All _Headers in Body Pane"), "H", NULL, G_CALLBACK(prefs_toggle_callback_impl), false },
     { "show-smilies-as-graphics", NULL, N_("Show _Smilies as Graphics"),      NULL, NULL, G_CALLBACK(prefs_toggle_callback_impl), true },
@@ -696,13 +726,14 @@ namespace pan
 
 
     { "work-online", "ICON_ONLINE", N_("_Work Online"), "L", NULL, G_CALLBACK(do_work_online), true },
-    { "tabbed-layout", GTK_STOCK_JUMP_TO, N_("_Tabbed Layout"), "Z", NULL, G_CALLBACK(do_tabbed_layout), false },
+    { "tabbed-layout", GTK_STOCK_JUMP_TO, N_("_Tabbed Layout"), "Z", NULL, G_CALLBACK(do_layout), false },
     { "show-group-pane", NULL, N_("Show Group _Pane"), "<control>1", NULL, G_CALLBACK(do_show_group_pane), true },
     { "show-header-pane", NULL, N_("Show Hea_der Pane"), "<control>2", NULL, G_CALLBACK(do_show_header_pane), true },
     { "show-body-pane", NULL, N_("Show Bod_y Pane"), "<control>3", NULL, G_CALLBACK(do_show_body_pane), true },
     { "show-toolbar", NULL, N_("Show _Toolbar"), NULL, NULL, G_CALLBACK(do_show_toolbar), true },
     { "shorten-group-names", GTK_STOCK_ZOOM_OUT, N_("Abbreviate Group Names"), "B", NULL, G_CALLBACK(do_shorten_group_names), false },
 
+    { "match-only-read-articles", "ICON_ONLY_READ", N_("Match Only _Read Articles"), NULL, N_("Match Only Read Articles"), G_CALLBACK(do_match_only_read_articles), false },
     { "match-only-unread-articles", "ICON_ONLY_UNREAD", N_("Match Only _Unread Articles"), NULL, N_("Match Only Unread Articles"), G_CALLBACK(do_match_only_unread_articles), false },
     { "match-only-cached-articles", "ICON_ONLY_CACHED", N_("Match Only _Cached Articles"), NULL, N_("Match Only Cached Articles"), G_CALLBACK(do_match_only_cached_articles), false },
     { "match-only-binary-articles", "ICON_ONLY_ATTACHMENTS", N_("Match Only _Complete Articles"), NULL, N_("Match Only Complete Articles"), G_CALLBACK(do_match_only_binary_articles), false },
@@ -716,7 +747,9 @@ namespace pan
     { "match-low-scoring-articles", NULL, N_("Match Scores of -9998...-1 (_Low)"), NULL, NULL, G_CALLBACK(do_match_low_scoring_articles), true },
     { "match-ignored-articles", NULL, N_("Match Scores of -9999 (_Ignored)"), NULL, NULL, G_CALLBACK(do_match_ignored_articles), false },
 
-    { "enable-rules", NULL, N_("Enable/Disable All _Rules"), "R", NULL, G_CALLBACK(do_toggle_rules), true    }
+    { "enable-rules", NULL, N_("Enable/Disable All _Rules"), "<shift>R", NULL, G_CALLBACK(do_toggle_rules), true }
+
+    //{"toggle-expand-thread", NULL, N_("Toggle expansion of selected thread"), NULL, NULL, G_CALLBACK(do_toggle_expand_thread), true }
   };
 
   const guint n_toggle_entries (G_N_ELEMENTS(toggle_entries));
