@@ -19,13 +19,14 @@
 #ifndef _actions_h_
 #define _actions_h_
 
-#include <gtk/gtk.h>
+#include "gtk-compat.h"
 #include <pan/gui/pan-ui.h>
 #include <pan/gui/prefs.h>
+#include <pan/data/data.h>
 
 namespace pan
 {
-  void add_actions (PanUI*, GtkUIManager*, Prefs*);
+  void add_actions (PanUI*, GtkUIManager*, Prefs*, Data*);
 }
 
 #endif /* __PAN_H__ */
