@@ -45,6 +45,10 @@ extern "C" {
 #include "gtk-compat.h"
 #include "save-attach-ui.h"
 
+#ifdef HAVE_WEBKIT
+  #include <webkit/webkit.h>
+#endif
+
 #define FIRST_PICTURE "first-picture"
 
 using namespace pan;
@@ -196,7 +200,7 @@ namespace
   void free_cursors (void)
   {
     for (int i=0; i<CURSOR_QTY; ++i)
-      gdk_cursor_unref (cursors[i]);
+      cursor_unref (cursors[i]);
   }
 
   void ensure_cursors_created (GtkWidget * w)
@@ -321,7 +325,7 @@ namespace
     {
       int x, y;
       if (event->is_hint)
-        gdk_window_get_pointer (event->window, &x, &y, NULL);
+        gdk_window_get_device_position (event->window, event->device, &x, &y, NULL);
       else {
         x = (int) event->x;
         y = (int) event->y;
@@ -454,6 +458,7 @@ BodyPane :: mouse_button_pressed (GtkWidget *w, GdkEventButton *event)
         const bool fullsize (toggle_fullsize_flag (buf));
         GtkAllocation aloc;
         gtk_widget_get_allocation(w, &aloc);
+//        std::cerr<<"457 alloc "<<aloc.x<<" "<<aloc.y<<" "<<aloc.width<<" "<<aloc.height<<"\n";
         resize_picture_at_iter (buf, &iter, fullsize, &aloc, pix_tag);
         gtk_text_iter_set_offset (&iter, offset);
         set_cursor_from_iter (event->window, w, &iter);
@@ -475,6 +480,7 @@ BodyPane :: mouse_button_pressed (GtkWidget *w, GdkEventButton *event)
 ***/
 namespace
 {
+
   GtkTextTag* get_or_create_tag (GtkTextTagTable * table, const char * key)
   {
     g_assert (table);
@@ -492,9 +498,19 @@ namespace
   void
   set_text_buffer_tags (GtkTextBuffer * buffer, const Prefs& p)
   {
+    const PanColors& colors (PanColors::get());
+    const std::string fg (p.get_color_str ("text-color-fg", colors.def_fg));
+    const std::string bg (p.get_color_str ("text-color-bg", colors.def_bg));
+
     GtkTextTagTable * table = gtk_text_buffer_get_tag_table (buffer);
+
     get_or_create_tag (table, "pixbuf");
     get_or_create_tag (table, "quote_0");
+
+    g_object_set (get_or_create_tag (table, "text"),
+      "foreground", p.get_color_str ("text-color-fg", fg).c_str(),
+      "background", p.get_color_str ("text-color-bg", bg).c_str(),
+      NULL);
     g_object_set (get_or_create_tag(table,"bold"),
       "weight", PANGO_WEIGHT_BOLD,
       NULL);
@@ -507,18 +523,23 @@ namespace
     g_object_set (get_or_create_tag (table, "url"),
       "underline", PANGO_UNDERLINE_SINGLE,
       "foreground", p.get_color_str ("body-pane-color-url", TANGO_SKY_BLUE_DARK).c_str(),
+      "background", p.get_color_str ("body-pane-color-url-bg", bg).c_str(),
       NULL);
     g_object_set (get_or_create_tag (table, "quote_1"),
       "foreground", p.get_color_str ("body-pane-color-quote-1", TANGO_CHAMELEON_DARK).c_str(),
+      "background", p.get_color_str ("body-pane-color-quote-1-bg", bg).c_str(),
       NULL);
     g_object_set (get_or_create_tag (table, "quote_2"),
       "foreground", p.get_color_str ("body-pane-color-quote-2", TANGO_ORANGE_DARK).c_str(),
+      "background", p.get_color_str ("body-pane-color-quote-2-bg", bg).c_str(),
       NULL);
     g_object_set (get_or_create_tag (table, "quote_3"),
       "foreground", p.get_color_str ("body-pane-color-quote-3", TANGO_PLUM_DARK).c_str(),
+      "background", p.get_color_str ("body-pane-color-quote-3-bg", bg).c_str(),
       NULL);
     g_object_set (get_or_create_tag (table, "signature"),
       "foreground", p.get_color_str ("body-pane-color-signature", TANGO_SKY_BLUE_LIGHT).c_str(),
+      "background", p.get_color_str ("body-pane-color-signature-bg", bg).c_str(),
       NULL);
   }
 }
@@ -756,6 +777,9 @@ namespace
     StringView v(body), line;
     GtkTextIter mark_start (start);
 
+    // colorize text
+    gtk_text_buffer_apply_tag_by_name (buffer, "text", &mark_start, &end);
+
     // find where the signature begins...
     const char * sig_point (0);
     int offset (0);
@@ -1024,8 +1048,8 @@ BodyPane :: append_part (GMimeObject * parent, GMimeObject * obj, GtkAllocation
     is_done = true;
   }
 
-  // otherwise, add to list of attachments
-  if (!is_done) {
+  // picture or otherwise, add to list of attachments
+  if (is_image || !is_done) {
     const char * filename = g_mime_part_get_filename (part);
     char * pch = (filename && *filename)
       ? g_strdup_printf ("%s", filename)
@@ -1124,6 +1148,29 @@ BodyPane :: set_text_from_message (GMimeMessage * message)
       l = add_header_line (s, message, _("Newsgroups"), "Newsgroups", fallback_charset);
       w = std::max (w, l);
     }
+	const StringView user_agent(
+			g_mime_object_get_header((GMimeObject *) message,
+					"User-Agent"));
+	if (!user_agent.empty()) {
+		l = add_header_line(s, message, _("User-Agent"), "User-Agent",
+				fallback_charset);
+		w = std::max(w, l);
+	}
+	const StringView x_newsreader(
+			g_mime_object_get_header((GMimeObject *) message,
+					"X-Newsreader"));
+	if (!x_newsreader.empty()) {
+		l = add_header_line(s, message, _("User-Agent"), "X-Newsreader",
+				fallback_charset);
+		w = std::max(w, l);
+	}
+	const StringView x_mailer(
+			g_mime_object_get_header((GMimeObject *) message, "X-Mailer"));
+	if (!x_mailer.empty()) {
+		l = add_header_line(s, message, _("User-Agent"), "X-Mailer",
+				fallback_charset);
+		w = std::max(w, l);
+	}
     const StringView followup_to (g_mime_object_get_header ((GMimeObject *) message, "Followup-To"));
     if (!followup_to.empty() && (followup_to!=newsgroups)) {
       l = add_header_line (s, message, _("Followup-To"), "Followup-To", fallback_charset);
@@ -1219,6 +1266,14 @@ BodyPane :: set_text_from_message (GMimeMessage * message)
   // set the text buffer...
   if (message)
     g_mime_message_foreach (message, foreach_part_cb, this);
+  // set the html view
+  GtkTextBuffer* buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(_text));
+  GtkTextIter _start, _end;
+  gtk_text_buffer_get_bounds (buffer, &_start, &_end);
+#ifdef HAVE_WEBKIT
+  char* buf (gtk_text_buffer_get_text (buffer, &_start, &_end, false));
+  if (buf) set_html_text(buf);
+#endif
 
   // if there was a picture, scroll to it.
   // otherwise scroll to the top of the body.
@@ -1434,7 +1489,7 @@ BodyPane :: text_size_allocated_idle ()
     if (gtk_text_iter_begins_tag (&iter, tag))
     {
       gtk_widget_get_allocation(_text, &aloc);
-      // BUG : resize
+//      std::cerr<<"1449 alloc "<<aloc.x<<" "<<aloc.y<<" "<<aloc.width<<" "<<aloc.height<<"\n";
       resize_picture_at_iter (buf, &iter, fullsize, &aloc, tag);
     }
     if (!gtk_text_iter_forward_char (&iter))
@@ -1555,7 +1610,7 @@ BodyPane :: new_attachment (const char* filename)
 {
   if (!filename) return 0;
 
-  GtkWidget* w = gtk_hbox_new(false, 0);
+  GtkWidget* w = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   GtkWidget* attachment = gtk_label_new(filename);
   GtkWidget * image = gtk_image_new_from_stock(GTK_STOCK_FILE, GTK_ICON_SIZE_MENU);
 
@@ -1584,7 +1639,7 @@ BodyPane :: clear_attachments()
 
   {
     gtk_container_remove (GTK_CONTAINER (_att_frame), _att_toolbar);
-    if (G_IS_OBJECT(_att_toolbar)) g_object_unref(_att_toolbar);
+    _att_toolbar = NULL;
     (void)create_attachments_toolbar(_att_frame);
   }
 
@@ -1598,7 +1653,7 @@ BodyPane :: add_attachment_to_toolbar (const char* fn)
   if (!fn) return;
 
   GtkWidget* w = new_attachment(fn);
-  gtk_widget_set_size_request(w, -1, 32);
+//  gtk_widget_set_size_request(w, -1, 32);
 
   ++_attachments;
 #if !GTK_CHECK_VERSION(3,0,0)
@@ -1615,9 +1670,7 @@ BodyPane :: add_attachment_to_toolbar (const char* fn)
   gtk_table_attach_defaults (GTK_TABLE(_att_toolbar), w, _cur_col, _cur_col+1, _cur_row,_cur_row+1);
 
   ++_cur_col;
-
 #else
-
   if (_attachments % 4 == 0 && _attachments != 0)
   {
     gtk_grid_insert_row (GTK_GRID(_att_toolbar), ++_cur_row);
@@ -1630,6 +1683,14 @@ BodyPane :: add_attachment_to_toolbar (const char* fn)
   gtk_widget_show_all(_att_toolbar);
 }
 
+#ifdef HAVE_WEBKIT
+void
+BodyPane :: set_html_text (const char* text)
+{
+  webkit_web_view_load_string (WEBKIT_WEB_VIEW (_web_view), text, NULL, NULL, "");
+}
+#endif
+
 GtkWidget*
 BodyPane :: create_attachments_toolbar (GtkWidget* frame)
 {
@@ -1674,6 +1735,9 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   _attachments(0),
   _current_attachment(0),
   _cleared (true)
+#ifdef HAVE_WEBKIT
+  ,_web_view (webkit_web_view_new ())
+#endif
 {
 
   GtkWidget * w, * l, * hbox;
@@ -1692,7 +1756,7 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   gtk_menu_shell_append (GTK_MENU_SHELL(_menu),l);
   gtk_widget_show_all(_menu);
 
-  GtkWidget * vbox = gtk_vbox_new (false, PAD);
+  GtkWidget * vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, PAD);
   gtk_container_set_resize_mode (GTK_CONTAINER(vbox), GTK_RESIZE_QUEUE);
 
   // about this expander... getting the ellipsis to work is a strange process.
@@ -1717,7 +1781,7 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   gtk_widget_show (_terse);
   g_signal_connect (_terse, "button-press-event", G_CALLBACK(verbose_clicked_cb), this);
 
-  hbox = _verbose = gtk_hbox_new (false, 0);
+  hbox = _verbose = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   g_object_ref_sink (G_OBJECT(_verbose));
   w = _headers = gtk_label_new ("Headers");
   gtk_label_set_selectable (GTK_LABEL(_headers), TRUE);
@@ -1768,7 +1832,23 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   gtk_expander_set_expanded (GTK_EXPANDER(_expander), expanded);
   expander_activated_idle (this);
 
-  _root = vbox;
+#ifdef HAVE_WEBKIT
+  w = gtk_notebook_new ();
+  GtkNotebook * n (GTK_NOTEBOOK (w));
+  gtk_notebook_append_page (n, vbox, gtk_label_new (_("Text View")));
+
+  // add scroll to html
+  GtkWidget* scroll = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(scroll), GTK_SHADOW_IN);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
+                                  GTK_POLICY_AUTOMATIC,
+                                  GTK_POLICY_AUTOMATIC);
+  gtk_container_add (GTK_CONTAINER(scroll), _web_view);
+  gtk_notebook_append_page (n, scroll, gtk_label_new (_("HTML View")));
+#else
+  w = vbox;
+#endif
+  _root = w;
   _prefs.add_listener (this);
 
   // listen for user interaction
@@ -2093,9 +2173,16 @@ BodyPane :: on_prefs_string_changed (const StringView& key, const StringView& va
 
 void
 BodyPane :: on_prefs_color_changed (const StringView& key, const GdkColor& color G_GNUC_UNUSED)
-{
-  if (key.strstr ("body-pane-color") != 0)
+{		
+  if ((key == "text-color-fg")              || (key == "text-color-bg")              || 
+      (key == "body-pane-color-url")        || (key == "body-pane-color-url-bg")     || 
+      (key == "body-pane-color-quote-1")    || (key == "body-pane-color-quote-2")    || 
+      (key == "body-pane-color-quote-3")    || (key == "body-pane-color-quote-1-bg") || 
+      (key == "body-pane-color-quote-2-bg") || (key == "body-pane-color-quote-3-bg") || 
+      (key == "body-pane-color-signature")  || (key == "body-pane-color-signature-bg"))
+  {
     refresh_colors ();
+  }
 }
 
 void
