@@ -60,10 +60,15 @@ namespace
       }
   };
 
+  Quark * virtual_title_quark (0);
   Quark * sub_title_quark (0);
   Quark * other_title_quark (0);
+
   bool is_group (const Quark& name) {
-    return !name.empty() && name!=*sub_title_quark && name!=*other_title_quark;
+    return !name.empty() &&
+        name!=*sub_title_quark &&
+        name!=*other_title_quark &&
+        name!=*virtual_title_quark;
   }
 
   std::string
@@ -318,6 +323,15 @@ namespace
 
   NoopRowDispose noop_row_dispose;
 
+  namespace
+  {
+  	//Local folders
+  	static const char* folders_groupnames[] = {
+            _("Sent"),
+            _("Drafts")
+          };
+  }
+
   PanTreeStore*
   build_model (const Data         & data,
                const TextMatch    * match,
@@ -329,7 +343,7 @@ namespace
     store->set_row_dispose (&noop_row_dispose);
 
     // find the groups that we'll be adding.
-    std::vector<Quark> groups, sub, unsub;
+    std::vector<Quark> groups, local_folders, sub, unsub;
     data.get_other_groups (groups);
     find_matching_groups (match, groups, unsub);
     groups.clear ();
@@ -340,16 +354,40 @@ namespace
     group_rows.clear ();
     group_rows.reserve (sub.size() + unsub.size());
 
-    MyRow * headers = new MyRow[2];
-    headers[0].groupname = *sub_title_quark;
-    headers[1].groupname = *other_title_quark;
+    MyRow * headers = new MyRow[3];
+    headers[0].groupname = *virtual_title_quark;
+    headers[1].groupname = *sub_title_quark;
+    headers[2].groupname = *other_title_quark;
     g_object_weak_ref (G_OBJECT(store), delete_rows, headers);
 
+    //
+    // local folders
+    //
+    MyRow * row = &headers[0];
+    store->append (NULL, row);
+    {
+		const size_t n (G_N_ELEMENTS(folders_groupnames));
+		std::vector<PanTreeStore::Row*> appendme;
+		appendme.reserve (n);
+		MyRow *rows(new MyRow [n]), *r(rows);
+		g_object_weak_ref (G_OBJECT(store), delete_rows, rows);
+
+		unsigned long unused;
+		for (size_t i(0); i!=n; ++i, ++r)
+		{
+			r->groupname = folders_groupnames[i];
+			data.get_group_counts (r->groupname, r->unread, unused);
+			appendme.push_back (r);
+			group_rows.push_back (r);
+		}
+		store->append (row, appendme);
+		expandme.push_back (store->get_iter (row));
+    }
     //
     //  subscribed
     //
 
-    MyRow * row = &headers[0];
+    row = &headers[1];
     store->append (NULL, row);
     if (!sub.empty())
     {
@@ -374,8 +412,7 @@ namespace
     //
     // unsubscribed
     //
-
-    row = &headers[1];
+    row = &headers[2];
     store->append (NULL, row);
     if (!unsub.empty())
     {
@@ -421,7 +458,7 @@ GroupPane :: on_group_subscribe (const Quark& groupname, bool sub)
   // find out where it should be moved to
   int pos (0);
   GtkTreeIter section_iter, group_iter;
-  if (gtk_tree_model_iter_nth_child (model, &section_iter, NULL, (sub?0:1))) {
+  if (gtk_tree_model_iter_nth_child (model, &section_iter, NULL, (sub?1:2))) {
     if (gtk_tree_model_iter_children (model, &group_iter, &section_iter)) do {
       MyRow * row (dynamic_cast<MyRow*>(_tree_store->get_row (&group_iter)));
       if (groupname.to_string() < row->groupname.c_str())
@@ -686,6 +723,8 @@ namespace
 {
   bool shorten;
 
+  std::string def_fg, def_bg;
+
   void
   render_group_name (GtkTreeViewColumn * ,
                      GtkCellRenderer   * renderer,
@@ -693,7 +732,8 @@ namespace
                      GtkTreeIter       * iter,
                      gpointer          gp)
   {
-	GroupPane* pane (static_cast<GroupPane*>(gp));
+
+    GroupPane* pane (static_cast<GroupPane*>(gp));
     PanTreeStore * tree (PAN_TREE_STORE(model));
     MyRow * row (dynamic_cast<MyRow*>(tree->get_row (iter)));
     const unsigned long& unread (row->unread);
@@ -709,25 +749,22 @@ namespace
       group_name += buf;
     }
 
-
-
-
     std::string fg_col(pane->get_group_prefs().get_group_color_str(name));
-    if (fg_col.empty())
-      fg_col = pane->get_prefs().get_color_str_wo_fallback("group-pane-fg-color");
-
     if (fg_col.empty())
     {
-      GdkColor def_fg;
-      GtkStyle *style = gtk_rc_get_style(pane->root());
-      if(!gtk_style_lookup_color(style, "text_color", &def_fg))
-        gdk_color_parse("black", &def_fg);
-      fg_col = GroupPrefs::color_to_string(def_fg);
+      fg_col = pane->get_prefs().get_color_str_wo_fallback("group-pane-color-fg");
+        if (fg_col.empty())
+          fg_col = def_fg;
     }
 
+    std::string bg_col (pane->get_prefs().get_color_str_wo_fallback("group-pane-color-bg"));
+    if (bg_col.empty())
+        bg_col = def_bg;
+
     g_object_set (renderer, "text", group_name.c_str(),
                             "weight", (!is_g || unread ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL),
-                            "foreground", fg_col.c_str(),
+                            "foreground", fg_col.empty() ? NULL : fg_col.c_str(),
+                            "background", bg_col.empty() ? NULL : bg_col.c_str(),
                             NULL);
   }
 }
@@ -755,9 +792,9 @@ GroupPane :: find_next_subscribed_group (bool unread_only)
   GtkTreeModel * model (gtk_tree_view_get_model (view));
 
   // find how many subscribed groups the tree's got
-  GtkTreeIter sub_iter;
-  gtk_tree_model_iter_nth_child (model, &sub_iter, 0, 0); // 'sub' node
-  const int n_groups = gtk_tree_model_iter_n_children (model, &sub_iter);
+  GtkTreeIter sub_iter, virtual_iter;
+  gtk_tree_model_iter_nth_child (model, &sub_iter, 0, 1); // 'sub' node
+  int n_groups = gtk_tree_model_iter_n_children (model, &sub_iter);
   if (n_groups < 1)
     return 0;
 
@@ -772,7 +809,7 @@ GroupPane :: find_next_subscribed_group (bool unread_only)
     GtkTreePath * path = gtk_tree_model_get_path (model, &sel_iter);
     gint depth = gtk_tree_path_get_depth (path);
     gint* indices = gtk_tree_path_get_indices (path);
-    if (depth==2 && indices[0]==0) // a subscribed group is selected
+    if (depth==2 && indices[0]==1) // a subscribed group is selected
       start_pos = indices[1];
     gtk_tree_path_free (path);
   }
@@ -793,9 +830,11 @@ GroupPane :: find_next_subscribed_group (bool unread_only)
     GtkTreeIter group_iter;
     gtk_tree_model_iter_nth_child (model, &group_iter, &sub_iter, n);
     const MyRow * row (dynamic_cast<MyRow*>(_tree_store->get_row (&group_iter)));
-    if (!unread_only || row->unread)
+    const bool is_virtual (is_virtual_group(row->groupname));
+    if (!is_virtual && (row->unread || !unread_only))
       return gtk_tree_model_get_path (model, &group_iter);
   }
+
 }
 
 void
@@ -804,7 +843,6 @@ GroupPane :: read_group (const StringView& groupname)
     GtkTreeView * view (GTK_TREE_VIEW (_tree_view));
     PanTreeStore * tree (PAN_TREE_STORE(gtk_tree_view_get_model(view)));
     GtkTreeIter iter;
-//    gtk_tree_model_iter_nth_child (model, &iter, 0, 0);
     const MyRow* row = find_row (groupname);
     iter = tree->get_iter (row);
     read_group(gtk_tree_model_get_path(gtk_tree_view_get_model(view), &iter));
@@ -913,6 +951,22 @@ GroupPane :: create_filter_entry ()
   return entry;
 }
 
+bool
+GroupPane :: is_virtual_group (const Quark& group)
+{
+  bool is_virtual = false;
+
+  for (int i(0); i != G_N_ELEMENTS(folders_groupnames); ++i)
+  {
+          if (group == folders_groupnames[i])
+          {
+                  is_virtual = true;
+                  break;
+          }
+  }
+  return is_virtual;
+}
+
 void
 GroupPane :: on_selection_changed (GtkTreeSelection*, gpointer pane_gpointer)
 {
@@ -925,8 +979,18 @@ GroupPane :: on_selection_changed (GtkTreeSelection*, gpointer pane_gpointer)
     "read-selected-group", "mark-groups-read", "delete-groups-articles",
     "get-new-headers-in-selected-groups", "download-headers"
   };
+  static const char* actions_in_nonvirtual_group[] = {
+    "show-group-preferences-dialog",
+    "subscribe", "unsubscribe",
+    "get-new-headers-in-selected-groups", "download-headers",
+    "refresh-group-list", "get-new-headers-in-subscribed-groups", "post"
+  };
   for (int i=0, n=G_N_ELEMENTS(actions_that_require_a_group); i<n; ++i)
     self->_action_manager.sensitize_action (actions_that_require_a_group[i], have_group);
+
+  // disable some functions for virtual mailbox folder
+  for (int i=0, n=G_N_ELEMENTS(actions_in_nonvirtual_group); i<n; ++i)
+    self->_action_manager.hide_action (actions_in_nonvirtual_group[i], is_virtual_group(group));
 }
 
 GroupPane :: GroupPane (ActionManager& action_manager, Data& data, Prefs& prefs, GroupPrefs& group_prefs):
@@ -937,7 +1001,13 @@ GroupPane :: GroupPane (ActionManager& action_manager, Data& data, Prefs& prefs,
   _action_manager (action_manager),
   _dirty_groups_idle_tag (0)
 {
+
+  const PanColors& colors (PanColors::get());
+  def_bg = colors.def_bg;
+  def_fg = colors.def_fg;
+
   shorten = prefs.get_flag ("shorten-group-names", false);
+  virtual_title_quark = new Quark (_("Local Folders"));
   sub_title_quark = new Quark (_("Subscribed Groups"));
   other_title_quark = new Quark (_("Other Groups"));
 
@@ -994,6 +1064,7 @@ GroupPane :: GroupPane (ActionManager& action_manager, Data& data, Prefs& prefs,
 
 GroupPane :: ~GroupPane ()
 {
+  delete virtual_title_quark;
   delete sub_title_quark;
   delete other_title_quark;
 
@@ -1036,6 +1107,6 @@ void
 GroupPane :: on_prefs_color_changed (const StringView& key, const GdkColor&)
 {
   if (key == "group-color")
-    refresh_font ();
     refresh_dirty_groups ();
+    refresh_font ();
 }
