@@ -40,6 +40,7 @@ extern "C" {
 #include <pan/tasks/task-xover.h>
 #include <pan/tasks/nzb.h>
 #include <pan/icons/pan-pixbufs.h>
+#include <pan/data-impl/rules-filter.h>
 #include "actions.h"
 #include "body-pane.h"
 #include "dl-headers-ui.h"
@@ -177,6 +178,11 @@ void GUI :: show_task_window_cb (GtkWidget *, gpointer gui_gpointer)
   static_cast<GUI*>(gui_gpointer)->activate_action ("show-task-window");
 }
 
+void GUI :: show_download_meter_prefs_cb (GtkWidget *, gpointer gui_gpointer)
+{
+  static_cast<GUI*>(gui_gpointer)->activate_action ("show-dl-meter-prefs");
+}
+
 void
 GUI :: root_realized_cb (GtkWidget*, gpointer self_gpointer)
 {
@@ -202,7 +208,7 @@ GUI :: root_realized_cb (GtkWidget*, gpointer self_gpointer)
     msg = gui->_cache.get_message(files);
 #endif
     gui->_body_pane->set_text_from_message(msg);
-
+    g_object_unref(msg);
   }
 }
 
@@ -213,8 +219,8 @@ GUI :: GUI (Data& data, Queue& queue, Prefs& prefs, GroupPrefs& group_prefs):
   _group_prefs (group_prefs),
   _cache (data.get_cache()),
   _encode_cache (data.get_encode_cache()),
-  _root (gtk_vbox_new (FALSE, 0)),
-  _menu_vbox (gtk_vbox_new (FALSE, 0)),
+  _root (gtk_box_new (GTK_ORIENTATION_VERTICAL, 0)),
+  _menu_vbox (gtk_box_new (GTK_ORIENTATION_VERTICAL, 0)),
   _group_pane (0),
   _header_pane (0),
   _body_pane (0),
@@ -267,7 +273,7 @@ GUI :: GUI (Data& data, Queue& queue, Prefs& prefs, GroupPrefs& group_prefs):
 
   // workarea
   _workarea_bin = gtk_event_box_new ();
-  do_tabbed_layout (is_action_active ("tabbed-layout"));
+  do_layout (is_action_active ("tabbed-layout"));
   gtk_box_pack_start (GTK_BOX(_root), _workarea_bin, TRUE, TRUE, 0);
   gtk_widget_show (_workarea_bin);
 
@@ -280,7 +286,7 @@ GUI :: GUI (Data& data, Queue& queue, Prefs& prefs, GroupPrefs& group_prefs):
   gtk_box_pack_start (GTK_BOX(_root), w, false, false, 0);
   gtk_widget_show (w);
 
-  GtkWidget * status_bar (gtk_hbox_new (FALSE, 0));
+  GtkWidget * status_bar (gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0));
 
   // connection status
   w = _connection_size_label = gtk_label_new (NULL);
@@ -294,6 +300,11 @@ GUI :: GUI (Data& data, Queue& queue, Prefs& prefs, GroupPrefs& group_prefs):
   gtk_container_add (GTK_CONTAINER(frame), w);
   gtk_box_pack_start (GTK_BOX(status_bar), frame, FALSE, FALSE, 0);
 
+  // drag and drop for message-ids
+  //  gtk_drag_dest_set(_workarea_bin,GTK_DEST_DEFAULT_ALL,target_list,3,GDK_ACTION_COPY);
+  //  gtk_drag_dest_add_text_targets(_workarea_bin);
+  //  gtk_drag_dest_add_uri_targets(_workarea_bin);
+
   // queue
   w = _queue_size_label = gtk_label_new (NULL);
   gtk_misc_set_padding (GTK_MISC(w), PAD, 0);
@@ -302,11 +313,6 @@ GUI :: GUI (Data& data, Queue& queue, Prefs& prefs, GroupPrefs& group_prefs):
   gtk_button_set_relief (GTK_BUTTON(w), GTK_RELIEF_NONE);
   g_signal_connect (w, "clicked", G_CALLBACK(show_task_window_cb), this);
 
-  // drag and drop for message-ids
-//  gtk_drag_dest_set(_workarea_bin,GTK_DEST_DEFAULT_ALL,target_list,3,GDK_ACTION_COPY);
-//  gtk_drag_dest_add_text_targets(_workarea_bin);
-//  gtk_drag_dest_add_uri_targets(_workarea_bin);
-
   gtk_container_add (GTK_CONTAINER(w), _queue_size_label);
   frame = gtk_frame_new (NULL);
   gtk_container_set_border_width (GTK_CONTAINER(frame), 0);
@@ -465,9 +471,7 @@ GUI :: watch_cursor_on ()
 {
   GdkCursor * cursor = gdk_cursor_new (GDK_WATCH);
   gdk_window_set_cursor ( gtk_widget_get_window(_root), cursor);
-  gdk_cursor_unref (cursor);
-//  while (gtk_events_pending ())
-//    gtk_main_iteration ();
+  cursor_unref (cursor);
 }
 
 void
@@ -536,6 +540,14 @@ GUI :: sensitize_action (const char * key, bool b) const
   //gtk_action_set_sensitive (get_action(key), b);
 }
 
+void
+GUI :: hide_action (const char * key, bool b) const
+{
+  ensure_action_map_loaded (_ui_manager);
+  g_object_set (get_action(key), "visible", gboolean(!b), NULL);
+  //gtk_action_set_sensitive (get_action(key), b);
+}
+
 
 void
 GUI :: toggle_action (const char * key, bool b) const
@@ -685,12 +697,14 @@ void GUI :: do_save_articles_to_nzb ()
   foreach_const (std::vector<const Article*>, articles, it)
     copies.push_back (**it);
 
+  const bool always (_prefs.get_flag("mark-downloaded-articles-read", false));
+
   const std::string file (GUI :: prompt_user_for_filename (get_window(_root), _prefs));
     if (!file.empty()) {
       Queue::tasks_t tasks;
       std::string emptystring;
       foreach_const (std::vector<Article>, copies, it)
-        tasks.push_back (new TaskArticle (_data, _data, *it, _cache, _data, 0, TaskArticle::RAW,emptystring));
+        tasks.push_back (new TaskArticle (_data, _data, *it, _cache, _data, always ? TaskArticle::ALWAYS_MARK : TaskArticle::NEVER_MARK, 0, TaskArticle::RAW,emptystring));
 
       // write them to a file
       std::ofstream tmp(file.c_str());
@@ -765,6 +779,7 @@ namespace
 
 void GUI :: do_save_articles_from_nzb ()
 {
+  const bool always (_prefs.get_flag("mark-downloaded-articles-read", false));
   const Article* article (_header_pane->get_first_selected_article ());
   if (article)
   {
@@ -773,7 +788,7 @@ void GUI :: do_save_articles_from_nzb ()
     {
       SaveArticlesFromNZB * listener = new SaveArticlesFromNZB (_data, _queue, _root,
                                                                 _prefs, _cache, _encode_cache, *article, path);
-      Task * t = new TaskArticle (_data, _data, *article, _cache, _data, listener);
+      Task * t = new TaskArticle (_data, _data, *article, _cache, _data, always ? TaskArticle::ALWAYS_MARK : TaskArticle::NEVER_MARK, listener);
       _queue.add_task (t, Queue::TOP);
     }
   }
@@ -833,6 +848,18 @@ void GUI :: do_import_tasks ()
     _queue.add_tasks (tasks, Queue::BOTTOM);
 }
 
+void GUI :: do_import_tasks_from_nzb_stream (const char* stream)
+{
+  // if we're importing files, build the tasks...
+  Queue::tasks_t tasks;
+  const std::string path (prompt_user_for_save_path (get_window(_root), _prefs));
+  if (!path.empty())
+    NZB :: tasks_from_nzb_string(stream, path, _cache, _encode_cache, _data, _data, _data, tasks);
+
+  if (!tasks.empty())
+    _queue.add_tasks (tasks, Queue::BOTTOM);
+}
+
 namespace
 {
   void task_pane_destroyed_cb (GtkWidget *, gpointer p)
@@ -989,9 +1016,11 @@ void GUI :: do_read_selected_article ()
   if (article)
   {
     const bool expand (_prefs.get_flag("expand-selected-articles",false));
+    const bool always (_prefs.get_flag("mark-downloaded-articles-read", false));
+
     if (expand) _header_pane->expand_selected ();
 
-    Task * t = new TaskArticle (_data, _data, *article, _cache, _data, this);
+    Task * t = new TaskArticle (_data, _data, *article, _cache, _data, always ? TaskArticle::ALWAYS_MARK : TaskArticle::NEVER_MARK, this);
     _queue.add_task (t, Queue::TOP);
   }
 }
@@ -999,9 +1028,10 @@ void GUI :: do_download_selected_article ()
 {
   typedef std::vector<const Article*> article_vector_t;
   const article_vector_t articles (_header_pane->get_full_selection_v ());
+  const bool always (_prefs.get_flag("mark-downloaded-articles-read", false));
   Queue::tasks_t tasks;
   foreach_const (article_vector_t, articles, it)
-    tasks.push_back (new TaskArticle (_data, _data, **it, _cache, _data));
+    tasks.push_back (new TaskArticle (_data, _data, **it, _cache, _data, always ? TaskArticle::ALWAYS_MARK : TaskArticle::NEVER_MARK));
   if (!tasks.empty())
     _queue.add_tasks (tasks, Queue::TOP);
 }
@@ -1138,6 +1168,16 @@ void GUI :: do_show_sec_dialog ()
 #endif
 }
 
+void GUI :: do_collapse_thread ()
+{
+  _header_pane->collapse_selected();
+}
+
+void GUI :: do_expand_thread ()
+{
+  _header_pane->expand_selected();
+}
+
 
 void GUI :: do_show_score_dialog ()
 {
@@ -1616,7 +1656,7 @@ void GUI :: do_tip_jar ()
 void GUI :: do_about_pan ()
 {
   const gchar * authors [] = { "Charles Kerr <charles@rebelbase.com> - Pan Author",
-                               "Heinrich M\u00fcller <eddie_v@gmx.de> - Developer",
+                               "Heinrich M\u00fcller <heinrich.mueller82@gmail.com> - Developer",
                                "Kenneth Haley <haleykd@users.sf.net> - Developer",
                                "Petr Kovar <pknbe@volny.cz> - Contributor",
                                "Calin Culianu <calin@ajvar.org> - Threaded Decoding",
@@ -1627,7 +1667,7 @@ void GUI :: do_about_pan ()
   gtk_about_dialog_set_program_name (w, _("Pan"));
   gtk_about_dialog_set_version (w, PACKAGE_VERSION);
   gtk_about_dialog_set_comments (w, VERSION_TITLE " (" GIT_REV "; " PLATFORM_INFO ")");
-  gtk_about_dialog_set_copyright (w, _("Copyright \u00A9 2002-2012 Charles Kerr and others")); // \u00A9 is unicode for (c)
+  gtk_about_dialog_set_copyright (w, _("Copyright \u00A9 2002-2016 Charles Kerr and others")); // \u00A9 is unicode for (c)
   gtk_about_dialog_set_website (w, "http://pan.rebelbase.com/");
   gtk_about_dialog_set_logo (w, logo);
   gtk_about_dialog_set_license (w, LICENSE);
@@ -1678,16 +1718,16 @@ namespace
       if (orient == VERTICAL) {
         if (uglyhack_idx==0)
         {
-          w = vpane = gtk_vpaned_new ();
+          w = vpane = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
         }
         else if (uglyhack_idx==2)
         {
-          w = sep_vpane = gtk_vpaned_new ();
+          w = sep_vpane = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
         }
         gtk_widget_set_size_request (w1, -1, 50);
         gtk_widget_set_size_request (w2, -1, 50);
       } else {
-        w = hpane = gtk_hpaned_new ();
+        w = hpane = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
         gtk_widget_set_size_request (w1, 50, -1);
         gtk_widget_set_size_request (w2, 50, -1);
       }
@@ -1725,7 +1765,8 @@ GUI :: notebook_page_switched_cb (GtkNotebook *, GtkNotebookPage *, gint page_nu
   g_idle_add (grab_focus_idle, w);
 }
 
-void GUI :: do_tabbed_layout (bool tabbed)
+//TODO
+void GUI :: do_layout (bool tabbed)
 {
   if (hpane) {
     _prefs.set_int ("main-window-hpane-position", gtk_paned_get_position(GTK_PANED(hpane)));
@@ -1740,6 +1781,7 @@ void GUI :: do_tabbed_layout (bool tabbed)
 
   GtkWidget * group_w (_group_pane->root());
   GtkWidget * header_w (_header_pane->root());
+  GtkWidget * search_w;
   GtkWidget * body_w (_body_pane->root());
 
   remove_from_parent (group_w);
@@ -1823,6 +1865,7 @@ void GUI :: do_shorten_group_names (bool b)
   _group_pane->set_name_collapse (b);
 }
 
+void GUI :: do_match_only_read_articles   (bool) { _header_pane->refilter (); }
 void GUI :: do_match_only_unread_articles (bool) { _header_pane->refilter (); }
 void GUI :: do_match_only_cached_articles (bool) { _header_pane->refilter (); }
 void GUI :: do_match_only_binary_articles (bool) { _header_pane->refilter (); }
@@ -1957,7 +2000,7 @@ void GUI :: do_read_selected_group ()
     // update iconv handler
     const char * from = g_mime_charset_iconv_name(local.c_str());
     char buf[256];
-    g_snprintf(buf, sizeof(buf), "%s//IGNORE", _prefs.get_string("default-charset", "UTF-8").c_str());
+    g_snprintf(buf, sizeof(buf), "%s//IGNORE", _prefs.get_string("default-charset", "UTF-8").str);
     const char * to  = g_mime_charset_iconv_name(buf);
     {
       if (iconv_inited)
@@ -2000,14 +2043,18 @@ void GUI :: do_read_selected_group ()
   // otherwise if get-new-headers is turned on, queue an xover-new task.
   unsigned long unread(0), total(0);
 
-  if (changed && !group.empty() && _queue.is_online()) {
+  if (changed && !group.empty()){
     _data.get_group_counts (group, unread, total);
-    if (!total)
-      activate_action ("download-headers");
-    else if (_prefs.get_flag("get-new-headers-when-entering-group", true)) {
-      if (_prefs.get_flag ("mark-group-read-before-xover", false))
-        _data.mark_group_read (group);
-      _queue.add_task (new TaskXOver (_data, group, TaskXOver::NEW), Queue::TOP);
+    const bool virtual_group (GroupPane::is_virtual_group(group));
+    if (!virtual_group)
+    {
+      if (!total)
+        activate_action ("download-headers");
+      else if (_prefs.get_flag("get-new-headers-when-entering-group", true)) {
+        if (_prefs.get_flag ("mark-group-read-before-xover", false))
+          _data.mark_group_read (group);
+        _queue.add_task (new TaskXOver (_data, group, TaskXOver::NEW), Queue::TOP);
+      }
     }
   }
 
@@ -2222,9 +2269,14 @@ GUI :: set_queue_size_label (unsigned int running,
     g_snprintf (str, sizeof(str), "%s: %u/%u", _("Tasks"), running, size);
 
   // build the tooltip
-  // todo : perhaps fix this for mac osx automatically....
+  // FIX : build fix for 64bit osx which doesn't seem to have guint64t nor gulong :(
+#ifdef G_OS_DARWIN
+  unsigned long queued, unused, stopped;
+  uint64_t KiB_remain;
+#else
   gulong queued, unused, stopped;
   guint64 KiB_remain;
+#endif
   double KiBps;
   int hr, min, sec;
   _queue.get_stats (queued, unused, stopped,
@@ -2292,15 +2344,20 @@ GUI :: on_queue_error (Queue&, const StringView& message)
 
 
 void
-GUI :: on_prefs_flag_changed (const StringView&, bool)
-{}
+GUI :: on_prefs_flag_changed (const StringView& key, bool val)
+{
+  if (key == "show-taskpane-popups")
+  {
+    _prefs.save();
+  }
+}
 
 
 void
 GUI :: on_prefs_string_changed (const StringView& key, const StringView& value)
 {
   if (key == "pane-layout" || key == "pane-orient")
-    GUI :: do_tabbed_layout (_prefs.get_flag ("tabbed-layout", false));
+    GUI :: do_layout (_prefs.get_flag ("tabbed-layout", false));
 
   if (key == "default-save-attachments-path")
     prev_path.assign (value.str, value.len);
