@@ -32,7 +32,8 @@
 #include <pan/gui/prefs.h>
 #include <pan/gui/group-prefs.h>
 #include <pan/gui/wait.h>
-//#include <pan/general/typedefs.h>
+
+#include <stdint.h>
 
 #include "gtk-compat.h"
 
@@ -60,6 +61,9 @@ namespace pan
   {
 
     public:
+
+      typedef std::vector<Quark> mid_sequence_t;
+
       GUI (Data& data, Queue&, Prefs&, GroupPrefs&);
       virtual ~GUI ();
       GtkWidget* root () { return _root; }
@@ -74,6 +78,9 @@ namespace pan
         std::string cert_name;
         int nr;
         GUI* gui;
+#ifdef HAVE_GNUTLS
+        void deinit_cert() { gnutls_x509_crt_deinit(cert); }
+#endif
       };
 
     public: // ActionManager
@@ -81,6 +88,7 @@ namespace pan
       virtual void activate_action (const char * action_name) const;
       virtual void toggle_action (const char * action_name, bool) const;
       virtual void sensitize_action (const char * action_name, bool) const;
+      virtual void hide_action (const char * key, bool b) const;
       virtual GtkWidget* get_action_widget (const char * key) const;
       virtual void disable_accelerators_when_focused (GtkWidget * entry) const;
 
@@ -98,6 +106,7 @@ namespace pan
       virtual void do_print ();
       virtual void do_quit ();
       virtual void do_import_tasks ();
+      virtual void do_import_tasks_from_nzb_stream (const char*);
       virtual void do_cancel_latest_task ();
       virtual void do_show_task_window ();
       virtual void do_show_log_window ();
@@ -132,6 +141,8 @@ namespace pan
       virtual void do_read_parent_article ();
       virtual void do_show_servers_dialog ();
       virtual void do_show_sec_dialog ();
+      virtual void do_collapse_thread ();
+      virtual void do_expand_thread ();
       virtual void do_show_selected_article_info ();
       virtual void do_plonk ();
       virtual void do_watch ();
@@ -161,7 +172,7 @@ namespace pan
       virtual void do_tip_jar ();
       virtual void do_about_pan ();
       virtual void do_work_online (bool);
-      virtual void do_tabbed_layout (bool);
+      virtual void do_layout (bool);
       virtual void do_show_toolbar (bool);
       virtual void do_show_group_pane (bool);
       virtual void do_show_header_pane (bool);
@@ -171,6 +182,7 @@ namespace pan
       virtual void do_match_only_binary_articles (bool);
       virtual void do_match_only_my_articles (bool);
       virtual void do_match_only_unread_articles (bool);
+      virtual void do_match_only_read_articles (bool);
       virtual void do_enable_toggle_rules (bool enable);
       virtual void do_match_on_score_state (int);
       virtual void do_show_matches (const Data::ShowType);
@@ -252,9 +264,12 @@ namespace pan
       GtkWidget * _event_log_button;
       GtkWidget * _taskbar;
       std::vector<ProgressView*> _views;
+      ProgressView* _meter_view;
       std::list<Task*> _active_tasks;
       std::string _charset;
 
+      GtkWidget* _meter_button;
+
       void set_charset (const StringView& v);
 
       void upkeep ();
@@ -265,11 +280,19 @@ namespace pan
 
       static void show_event_log_cb (GtkWidget*, gpointer);
       static void show_task_window_cb (GtkWidget*, gpointer);
+      static void show_download_meter_prefs_cb (GtkWidget*, gpointer);
 
       void score_add (int);
 
       static void notebook_page_switched_cb (GtkNotebook*, GtkNotebookPage*, gint, gpointer);
 
+      static void root_realized_cb (GtkWidget*, gpointer self_gpointer);
+
+    public:
+      BodyPane* body_pane() { return _body_pane; }
+
+      GtkWidget* meter_button () { return _meter_button; }
+
     private:
       static void add_widget (GtkUIManager*, GtkWidget*, gpointer);
       static void server_list_dialog_destroyed_cb (GtkWidget*, gpointer);
