@@ -36,6 +36,7 @@ namespace pan
     virtual void do_save_articles_to_nzb () = 0;
     virtual void do_print () = 0;
     virtual void do_import_tasks () = 0;
+    virtual void do_import_tasks_from_nzb_stream (const char*) = 0;
     virtual void do_cancel_latest_task () = 0;
     virtual void do_select_all_articles () = 0;
     virtual void do_unselect_all_articles () = 0;
@@ -66,12 +67,20 @@ namespace pan
     virtual void do_plonk () = 0;
     virtual void do_watch () = 0;
     virtual void do_ignore () = 0;
+    virtual void do_flag () = 0;
+    virtual void do_flag_off () = 0;
+    virtual void do_next_flag () = 0;
+    virtual void do_last_flag () = 0;
+    virtual void do_mark_all_flagged () = 0;
+    virtual void do_invert_selection () = 0;
     virtual void do_cancel_article () = 0;
     virtual void do_supersede_article () = 0;
     virtual void do_delete_article () = 0;
     virtual void do_clear_article_cache () = 0;
     virtual void do_mark_article_read () = 0;
     virtual void do_mark_article_unread () = 0;
+    virtual void do_mark_thread_read () = 0;
+    virtual void do_mark_thread_unread () = 0;
     virtual void do_post () = 0;
     virtual void do_followup_to () = 0;
     virtual void do_reply_to () = 0;
@@ -87,10 +96,14 @@ namespace pan
     virtual void do_show_group_preferences_dialog () = 0;
     virtual void do_show_profiles_dialog () = 0;
     virtual void do_show_servers_dialog () = 0;
+    virtual void do_show_sec_dialog () = 0;
     virtual void do_show_score_dialog () = 0;
     virtual void do_show_new_score_dialog () = 0;
     virtual void do_show_selected_article_info () = 0;
 
+    virtual void do_collapse_thread () = 0;
+    virtual void do_expand_thread () = 0;
+
     virtual void do_read_selected_group () = 0;
     virtual void do_mark_selected_groups_read () = 0;
     virtual void do_clear_selected_groups () = 0;
@@ -102,7 +115,7 @@ namespace pan
     virtual void do_unsubscribe_selected_groups () = 0;
 
     virtual void do_work_online (bool) = 0;
-    virtual void do_tabbed_layout (bool) = 0;
+    virtual void do_layout (bool) = 0;
 
     virtual void do_show_group_pane (bool) = 0;
     virtual void do_show_header_pane (bool) = 0;
@@ -110,12 +123,15 @@ namespace pan
     virtual void do_show_toolbar (bool) = 0;
     virtual void do_shorten_group_names (bool) = 0;
 
+    virtual void do_match_only_read_articles (bool) = 0;
     virtual void do_match_only_unread_articles (bool) = 0;
     virtual void do_match_only_cached_articles (bool) = 0;
     virtual void do_match_only_binary_articles (bool) = 0;
     virtual void do_match_only_my_articles (bool) = 0;
     virtual void do_show_matches (const Data::ShowType) = 0;
 
+    virtual void do_enable_toggle_rules (bool enable) = 0;
+
 #define MATCH_IGNORED         (1<<0)
 #define MATCH_LOW_SCORING     (1<<1)
 #define MATCH_NORMAL_SCORING  (1<<2)
