@@ -18,8 +18,6 @@
  */
 
 
-// TODO :: fix usage of gkr!!
-
 #include <memory>
 #include <fstream>
 #include <config.h>
@@ -33,6 +31,7 @@ extern "C" {
   #include <sys/types.h>
   #include <sys/stat.h>
   #include <unistd.h>
+  #include <uulib/crc32.h>
 }
 
 #ifdef G_OS_WIN32
@@ -110,7 +109,14 @@ namespace
 
   gboolean delete_event_cb (GtkWidget * w, GdkEvent *, gpointer user_data)
   {
-    mainloop_quit ();
+    if (static_cast<Prefs*>(user_data)->get_flag("status-icon", false))
+    {
+      gtk_widget_hide(w);
+    }
+    else
+    {
+      mainloop_quit ();
+    }
     return true; // don't invoke the default handler that destroys the widget
   }
 
@@ -195,12 +201,23 @@ namespace
 
     GtkWindow * window = GTK_WINDOW(data);
 
-    if (gtk_window_is_active(window))
+    GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET(window));
+    GdkWindow *gdkwindow = gtk_widget_get_window (toplevel);
+    GdkWindowState state = gdk_window_get_state (gdkwindow);
+    gboolean maximized = state & GDK_WINDOW_STATE_MAXIMIZED;
+    gboolean iconified = state & GDK_WINDOW_STATE_ICONIFIED;
+
+//    std::cerr<<(state & GDK_WINDOW_STATE_MAXIMIZED)<<" "
+//    <<(state & GDK_WINDOW_STATE_ICONIFIED)<<" "
+//    <<(state & GDK_WINDOW_STATE_WITHDRAWN)<<" "
+//    <<(state & GDK_WINDOW_STATE_FULLSCREEN)<<"\n" ;
+
+    if (maximized || (maximized && iconified))
     {
       gtk_window_iconify (window);
       gtk_widget_hide (GTK_WIDGET(window));
     }
-    else
+    else if (!maximized || iconified)
     {
       gtk_widget_show (GTK_WIDGET(window));
       gtk_window_deiconify(window);
@@ -251,11 +268,11 @@ namespace
       prefs.add_listener(this);
       queue.add_listener(this);
       data.add_listener(this);
+      is_online = q.is_online();
+
       update_status_tooltip();
       status_icon_timeout_tag = g_timeout_add (500, status_icon_periodic_refresh, this);
 
-      is_online = q.is_online();
-
       update_status_icon(ICON_STATUS_IDLE);
 
     }
@@ -502,21 +519,21 @@ namespace
 
     GUI& gui (*_gui);
 
-    const gulong delete_cb_id =  g_signal_connect (window, "delete-event", G_CALLBACK(delete_event_cb), NULL);
+    const gulong delete_cb_id =  g_signal_connect (window, "delete-event", G_CALLBACK(delete_event_cb), &prefs);
 
     gtk_container_add (GTK_CONTAINER(window), gui.root());
     const bool minimized(prefs.get_flag("start-minimized", false));
-    const bool status_icon(prefs.get_flag("start-minimized", false));
 
-    if (minimized) gtk_window_iconify (window);
+    if (minimized)
+      gtk_window_iconify (window);
 
-    gtk_widget_show (GTK_WIDGET(window));
+    gtk_widget_set_visible (GTK_WIDGET(window), !minimized);
 
     const quarks_t servers (data.get_servers ());
     if (servers.empty())
     {
       const Quark empty_server;
-      GtkWidget * w = server_edit_dialog_new (data, queue, window, empty_server);
+      GtkWidget * w = server_edit_dialog_new (data, queue, prefs, window, empty_server);
       gtk_widget_show_all (w);
       GtkWidget * msg = gtk_message_dialog_new (GTK_WINDOW(w),
                                                 GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -610,12 +627,10 @@ _("General Options\n"
 "\n"
 "URL Options\n"
 
-// Doesn't work yet.
-/*"  news:message-id          Show the specified article.\n"
-"  news:group.name          Show the specified newsgroup.\n"
+// NOT IMPLEMENTED
+//"  news:message-id          Show the specified article.\n"
+//"  news:group.name          Show the specified newsgroup.\n"
 "  headers:group.name       Download new headers for the specified newsgroup.\n"
-*/
-
 "  --no-gui                 On news:message-id, dump the article to stdout.\n"
 "\n"
 "NZB Batch Options\n"
@@ -808,6 +823,59 @@ namespace
   GUI * gui_ptr (0);
 }
 
+namespace
+{
+  void init_colors()
+  {
+
+    GtkWidget* r = gtk_label_new("bla");
+
+    GdkColor def_fg, def_bg;
+    std::string fg_col, bg_col;
+
+    // init colors of PanColors
+#if GTK_CHECK_VERSION(3,0,0)
+    GdkRGBA fg_color, bg_color;
+    GtkStyleContext* ctx = gtk_widget_get_style_context(r);
+    if(!ctx || !gtk_style_context_lookup_color(ctx, "color", &fg_color))
+      gdk_color_parse("black", &def_fg);
+    else
+    {
+      def_fg.red = fg_color.red;
+      def_fg.green = fg_color.red;
+      def_fg.blue = fg_color.blue;
+    }
+    if(!ctx || !gtk_style_context_lookup_color(ctx, "background-color", &bg_color))
+      gdk_color_parse("white", &def_bg);
+    else
+    {
+      def_bg.red = bg_color.red;
+      def_bg.green = bg_color.red;
+      def_bg.blue = bg_color.blue;
+    }
+#else
+    GtkStyle *style = gtk_rc_get_style(r);
+    if(!style || !gtk_style_lookup_color(style, "text_color", &def_fg))
+      gdk_color_parse("black", &def_fg);
+    if(!style || !gtk_style_lookup_color(style, "bg_color", &def_bg))
+      gdk_color_parse("white", &def_bg);
+
+#endif
+
+    //todo move to pancolors
+    fg_col = GroupPrefs::color_to_string(def_fg);
+    bg_col = GroupPrefs::color_to_string(def_bg);
+
+    gtk_widget_destroy (r);
+
+    PanColors& c (PanColors::get());
+    c.def_fg = fg_col;
+    c.def_bg = bg_col;
+    c.def_fg_col = def_fg;
+    c.def_bg_col = def_bg;
+  }
+
+}
 
 int
 main (int argc, char *argv[])
@@ -828,6 +896,8 @@ main (int argc, char *argv[])
   std::string nzb_output_path;
   strings_v nzb_files;
   std::string nzb_str;
+  bool fatal_dbg(true);
+  bool console_active(false);
 
   for (int i=1; i<argc; ++i)
   {
@@ -838,8 +908,8 @@ main (int argc, char *argv[])
       url = tok;
     else if (!strcmp(tok,"--no-gui") || !strcmp(tok,"--nogui"))
       gui = false;
-    else if (!strcmp (tok, "--debug")) { // do --debug --debug for verbose debug
-      console();
+    else if (!strcmp (tok, "--debug")) { // use --debug --debug for verbose debug
+      if (!console_active) { console_active = true; console(); }
       if (_debug_flag) _debug_verbose_flag = true;
       else _debug_flag = true;
     } else if (!strcmp (tok, "--nzb"))
@@ -860,8 +930,10 @@ main (int argc, char *argv[])
     else if (!strcmp(tok,"-h") || !strcmp(tok,"--help"))
       { usage (); return EXIT_SUCCESS; }
     else if (!strcmp(tok, "--verbose") )
+    {
+      if (!console_active) { console_active = true; console(); }
       verbosed = true;
-    else {
+    } else {
       nzb = true;
       nzb_files.push_back (tok);
       if (nzb_files.size() > 1) nzb_str +=" ";
@@ -873,12 +945,14 @@ main (int argc, char *argv[])
   setlocale(LC_ALL,"C");
 #endif
 
-  if (verbosed && !gui && nzb)
+  if (verbosed && !gui)
     _verbose_flag = true;
 
-
   if (gui)
+  {
     gtk_init (&argc, &argv);
+    init_colors();
+  }
 
   if (!gui && nzb_files.empty() && url.empty() && groups.empty()) {
     std::cerr << _("Error: --no-gui used without nzb files or news:message-id.") << std::endl;
@@ -887,10 +961,11 @@ main (int argc, char *argv[])
 
   Log::add_info_va (_("Pan %s started"), VERSION);
 
+  if (gui)
   {
     // load the preferences...
     char * filename = g_build_filename (file::get_pan_home().c_str(), "preferences.xml", NULL);
-    PrefsFile prefs (filename);
+    PrefsFile prefs (filename); // dummy is used to get fg/bg colors from UI
     g_free (filename);
     filename = g_build_filename (file::get_pan_home().c_str(), "group-preferences.xml", NULL);
     GroupPrefs group_prefs (filename);
@@ -898,7 +973,7 @@ main (int argc, char *argv[])
 
     // instantiate the backend...
     const int cache_megs = prefs.get_int ("cache-size-megs", 10);
-    DataImpl data (prefs.get_string("cache-file-extension","msg"), false, cache_megs);
+    DataImpl data (prefs.get_string("cache-file-extension","msg"), prefs, false, cache_megs);
     ArticleCache& cache (data.get_cache ());
     EncodeCache& encode_cache (data.get_encode_cache());
     CertStore& certstore (data.get_certstore());
@@ -912,8 +987,7 @@ main (int argc, char *argv[])
     // instantiate the queue...
     WorkerPool worker_pool (4, true);
     SocketCreator socket_creator(data, certstore);
-    Queue queue (data, data, &socket_creator, certstore, worker_pool, false, 32768);
-    data.set_queue (&queue);
+    Queue queue (data, data, data, &socket_creator, certstore, prefs, worker_pool, false, 32768);
 
 #ifdef HAVE_DBUS
     Pan pan(data, queue, cache, encode_cache, prefs, group_prefs);
@@ -1019,7 +1093,6 @@ main (int argc, char *argv[])
       gtk_window_set_resizable (GTK_WINDOW(window), true);
       gtk_window_set_default_icon (pixbuf);
 
-
       gui_ptr = new GUI (data, queue, prefs, group_prefs);
 
 #ifdef HAVE_LIBNOTIFY
