@@ -40,6 +40,8 @@ const char * fallback_ui_file =
 "        <menuitem action='shorten-group-names' />\n"
 "      </menu>\n"
 "      <menu action='view-header-pane-menu'>\n"
+"        <menuitem action='toggle-expand-thread' />\n"
+"        <separator />\n"
 "        <menuitem action='thread-headers' />\n"
 "        <separator />\n"
 "        <menuitem action='enable-rules' />\n"
@@ -49,6 +51,7 @@ const char * fallback_ui_file =
 "        <menuitem action='show-matching-subthreads' />\n"
 "        <separator />\n"
 "        <menuitem action='match-only-unread-articles' />\n"
+"        <menuitem action='match-only-read-articles' />\n"
 "        <menuitem action='match-only-cached-articles' />\n"
 "        <menuitem action='match-only-binary-articles' />\n"
 "        <menuitem action='match-only-my-articles' />\n"
@@ -62,6 +65,7 @@ const char * fallback_ui_file =
 "      </menu>\n"
 "      <menu action='view-body-pane-menu'>\n"
 "        <menuitem action='wrap-article-body' />\n"
+"        <menuitem action='show-article-sig' />\n"
 "        <menuitem action='mute-quoted-text' />\n"
 "        <menuitem action='show-all-headers' />\n"
 "        <menuitem action='monospace-font-enabled' />\n"
@@ -176,12 +180,14 @@ const char * fallback_ui_file =
 "    <placeholder name='header-pane-filter' />\n"
 "    <separator />\n"
 "    <toolitem action='match-only-unread-articles' />\n"
+"    <toolitem action='match-only-read-articles' />\n"
 "    <toolitem action='match-only-cached-articles' />\n"
 "    <toolitem action='match-only-binary-articles' />\n"
 "    <toolitem action='match-only-my-articles' />\n"
 "    <toolitem action='match-only-watched-articles' />\n"
 "    <separator />\n"
 "    <toolitem action='wrap-article-body' />\n"
+"    <toolitem action='show-article-sig' />\n"
 "  </toolbar>\n"
 "\n"
 "  <popup name='header-pane-popup'>\n"
