@@ -28,6 +28,7 @@ extern "C" {
 #include <pan/tasks/task-article.h>
 #include <pan/tasks/queue.h>
 #include <pan/usenet-utils/text-massager.h>
+#include <pan/data-impl/rules-filter.h>
 #include "hig.h"
 #include "pad.h"
 #include "pan-file-entry.h"
@@ -104,7 +105,9 @@ SaveAttachmentsDialog :: response_cb (GtkDialog * dialog,
     if ((path.find("%s") != path.npos) || (path.find("%S") != path.npos))
       subject_in_path = true;
 
-    std::string sep( self->_prefs.get_string("save-subj-seperator", "-") );
+    std::string sep( self->_prefs.get_string("save-subj-separator", "-") );
+
+    const bool always (self->_prefs.get_flag("mark-downloaded-articles-read", false));
 
     // make the tasks...
     Queue::tasks_t tasks;
@@ -117,6 +120,7 @@ SaveAttachmentsDialog :: response_cb (GtkDialog * dialog,
                                         *it,
                                         self->_cache,
                                         self->_read,
+                                        always ? TaskArticle::ALWAYS_MARK : TaskArticle::NEVER_MARK,
                                         0,
                                         TaskArticle::DECODE,
                                         path,
@@ -227,7 +231,7 @@ SaveAttachmentsDialog :: SaveAttachmentsDialog
   GtkWidget * dialog = gtk_dialog_new_with_buttons (_("Pan: Save Attachments"),
                                                     parent_window,
                                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                    NULL);
+                                                    NULL, NULL);
   gtk_dialog_add_button (GTK_DIALOG(dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
   GtkWidget * focus = gtk_dialog_add_button (GTK_DIALOG(dialog), GTK_STOCK_SAVE, GTK_RESPONSE_OK);
   gtk_window_set_role (GTK_WINDOW(dialog), "pan-save-attachments-dialog");
@@ -247,7 +251,7 @@ SaveAttachmentsDialog :: SaveAttachmentsDialog
   if (path_mode==PATH_GROUP && !have_group_default)
       path_mode = PATH_ENTRY;
 
-  h = gtk_hbox_new (FALSE, 0);
+  h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   if (have_group_default) {
     w = _save_custom_path_radio = gtk_radio_button_new_with_mnemonic (NULL, _("_Location:"));
     gtk_box_pack_start (GTK_BOX(h), w, false, false, 0);
