@@ -191,11 +191,11 @@ NNTP_Pool :: on_socket_created (const StringView  & host,
     {
       std::string pw (pass ? pass : "");
       if (pass) g_free(pass);
-      nntp = new NNTP (_server, user, pw, socket);
+      nntp = new NNTP (_server, user, pw, _server_info, socket);
     }
     else
     {
-      nntp = new NNTP (_server, user, pass, socket);
+      nntp = new NNTP ( _server, user, pass, _server_info, socket);
     }
     nntp->handshake (this);
   }
@@ -222,7 +222,8 @@ NNTP_Pool :: on_nntp_done (NNTP* nntp, Health health, const StringView& response
          || (s.find ("480") != s.npos) // http://bugzilla.gnome.org/show_bug.cgi?id=409085
          || (s.find ("too many") != s.npos)
          || (s.find ("limit reached") != s.npos)
-         || (s.find ("maximum number of connections") != s.npos))
+         || (s.find ("maximum number of connections") != s.npos)
+         || (s.find ("multiple") != s.npos) )
      {
        disallow_new_connections_for_n_seconds (TOO_MANY_CONNECTIONS_LOCKOUT_SECS);
      }
@@ -300,8 +301,7 @@ NNTP_Pool :: request_nntp (WorkerPool& threadpool)
     if (!_certstore.in_blacklist(_server))
     {
       ++_pending_connections;
-      const bool ssl(_server_info.get_server_ssl_support(_server));
-      _socket_creator->create_socket (_server_info, address, port, threadpool, this, ssl);
+      _socket_creator->create_socket (_server_info, _server, address, port, threadpool, this);
     }
   }
 }
