@@ -61,6 +61,7 @@ NNTP :: fire_done_func (Health health, const StringView& response)
    {
       Listener * l = _listener;
       debug ("I (" << (void*)this << ") am setting my _listener to 0");
+      _compression = false;
       _listener = 0;
       l->on_nntp_done (this, health, response);
    }
@@ -73,6 +74,7 @@ NNTP :: fire_done_func (Health health, const StringView& response)
 bool
 NNTP :: on_socket_response (Socket * sock UNUSED, const StringView& line_in)
 {
+
    enum State { CMD_FAIL, CMD_DONE, CMD_MORE, CMD_NEXT, CMD_RETRY };
    State state;
    StringView line (line_in);
@@ -81,18 +83,17 @@ NNTP :: on_socket_response (Socket * sock UNUSED, const StringView& line_in)
    if (line.len>=2 && line.str[line.len-2]=='\r' && line.str[line.len-1]=='\n')
      line.truncate (line.len-2);
 
-//    std::cerr <<"_nntp_response_text: " << _nntp_response_text<<std::endl;
    if (_nntp_response_text)
    {
+      state = CMD_MORE;
+
       if (line.len==1 && line.str[0]=='.') // end-of-list
       {
          state = CMD_DONE;
          _nntp_response_text = false;
       }
-      else
+      else if (!_compression)
       {
-         state = CMD_MORE;
-
          if (line.len>=2 && line.str[0]=='.' && line.str[1]=='.') // rfc 977: 2.4.1
             line.rtruncate (line.len-1);
 
@@ -100,138 +101,172 @@ NNTP :: on_socket_response (Socket * sock UNUSED, const StringView& line_in)
          if (_listener)
             _listener->on_nntp_line (this, line);
       }
-   }
-   else switch (atoi (line.str))
-   {
-      case SERVER_READY:
-      case SERVER_READY_NO_POSTING:
-      case SERVER_READY_STREAMING_OK:
-         state = CMD_DONE;
-         break;
 
-      case ARTICLE_POSTED_OK:
-      case GOODBYE:
-      case XOVER_NO_ARTICLES:
-         state = CMD_DONE;
-         break;
+      if (_compression)
+      {
 
-      case AUTH_REQUIRED: { // must send username
-         if (!_username.empty()) {
-           _commands.push_front (_previous_command);
-           _socket->write_command_va (this, "AUTHINFO USER %s\r\n", _username.c_str());
-           state = CMD_NEXT;
-         } else {
-           std::string host;
-           _socket->get_host (host);
-           Log::add_err_va (_("%s requires a username, but none is set."), host.c_str());
-           state = CMD_FAIL;
-         }
-         break;
-      }
+        StringView l(line);
+        if (_listener)
+          _listener->on_nntp_line (this, l);
 
-      case AUTH_NEED_MORE: { // must send password
-        if (!_password.empty()) {
-           _socket->write_command_va (this, "AUTHINFO PASS %s\r\n", _password.c_str());
-           state = CMD_NEXT;
-        } else {
-           std::string host;
-           _socket->get_host (host);
-           Log::add_err_va (_("%s requires a password, but none is set."), host.c_str());
-           state = CMD_FAIL;
-        }
-        break;
-      }
-
-      case AUTH_ACCEPTED:
-         state = CMD_DONE;
-         break;
-
-      case GROUP_RESPONSE: {
-         // response is of form "211 qty low high group_name"
-         StringView tok, myline (line);
-         myline.pop_token (tok, ' ');
-         myline.pop_token (tok, ' ');
-         const unsigned long aqty (strtoul (tok.str, NULL, 10));
-         myline.pop_token (tok, ' ');
-         const unsigned long alo (strtoul (tok.str, NULL, 10));
-         myline.pop_token (tok, ' ');
-         const unsigned long ahi (strtoul (tok.str, NULL, 10));
-         myline.pop_token (tok, ' ');
-         const pan::Quark group (tok);
-         if (_listener)
-            _listener->on_nntp_group (this, group, aqty, alo, ahi);
-         _group = group;
-          state = CMD_DONE;
-         break;
-      }
-
-      case SEND_ARTICLE_NOW:
-         // ready to get article; send it now
-         _socket->write_command (_post, this);
-         state = CMD_NEXT;
-         break;
-
-      case NO_POSTING:
-      case POSTING_FAILED:
-        // if we hit a dupe, we silently continue
-        if (line.strstr("435"))
+        if (l.str[l.len-1]=='.') // gzip compression, ends with a single "."
         {
+          _nntp_response_text = false;
+          _compression = false;
           state = CMD_DONE;
+        }
+      }
+   }
+   else
+   {
+     //check for compression, enable once, disable at end
+     if (!_compression)
+       _compression = strcasestr (line_in.str, COMPRESS_GZIP);
+
+     switch (atoi (line.str))
+     {
+        case SERVER_READY:
+        case SERVER_READY_NO_POSTING:
+        case SERVER_READY_STREAMING_OK:
+           state = CMD_DONE;
+           break;
+
+        case ARTICLE_POSTED_OK:
+        case GOODBYE:
+        case XOVER_NO_ARTICLES:
+           state = CMD_DONE;
+           break;
+
+        case AUTH_REQUIRED: { // must send username
+           if (!_username.empty()) {
+             _commands.push_front (_previous_command);
+             _socket->write_command_va (this, "AUTHINFO USER %s\r\n", _username.c_str());
+             state = CMD_NEXT;
+           } else {
+             std::string host;
+             _socket->get_host (host);
+             Log::add_err_va (_("%s requires a username, but none is set."), host.c_str());
+             state = CMD_FAIL;
+           }
+           break;
+        }
+
+        case AUTH_NEED_MORE: { // must send password
+          if (!_password.empty()) {
+             _socket->write_command_va (this, "AUTHINFO PASS %s\r\n", _password.c_str());
+             state = CMD_NEXT;
+          } else {
+             std::string host;
+             _socket->get_host (host);
+             Log::add_err_va (_("%s requires a password, but none is set."), host.c_str());
+             state = CMD_FAIL;
+          }
           break;
         }
-      case GROUP_NONEXISTENT:
-         state = CMD_FAIL;
-         break;
 
-      case XOVER_FOLLOWS:
-      case ARTICLE_FOLLOWS:
-      case NEWGROUPS_FOLLOWS:
-      case INFORMATION_FOLLOWS:
-         state = CMD_MORE;
-         _nntp_response_text = true;
-         break;
+        case AUTH_ACCEPTED:
+          CompressionType ctype;
+           _server_info.get_server_compression_type(_server, ctype);
+           if (ctype == HEADER_COMPRESS_XFEATURE)
+           {
+             // try to enable compression xfeature
+             _socket->write_command (ENABLE_COMPRESS_GZIP, this);
+             state = CMD_NEXT;
+           } else
+             state = CMD_DONE;
+           break;
 
-      case AUTH_REJECTED:
-      case NO_GROUP_SELECTED:
-      case ERROR_CMD_NOT_UNDERSTOOD:
-      case ERROR_CMD_NOT_SUPPORTED:
-      case NO_PERMISSION:
-      case FEATURE_NOT_SUPPORTED: {
-         std::string cmd (_previous_command);
-         if (cmd.size()>=2 && cmd[cmd.size()-1]=='\n' && cmd[cmd.size()-2]=='\r')
-           cmd.resize (cmd.size()-2);
-         std::string host;
-         _socket->get_host (host);
-         Log::add_err_va (_("Sending \"%s\" to %s returned an error: %s"),
-                          cmd.c_str(),
-                          host.c_str(),
-                          line.to_string().c_str());
-         state = CMD_FAIL;
-         break;
-      }
+        case FEATURE_ENABLED:
+           state= CMD_DONE;
+           break;
 
-      case NO_SUCH_ARTICLE_NUMBER:
-      case NO_SUCH_ARTICLE:
-         state = CMD_FAIL;
-         break;
+        case GROUP_RESPONSE: {
+           // response is of form "211 qty low high group_name"
+           StringView tok, myline (line);
+           myline.pop_token (tok, ' ');
+           myline.pop_token (tok, ' ');
+           const unsigned long aqty (strtoul (tok.str, NULL, 10));
+           myline.pop_token (tok, ' ');
+           const unsigned long alo (strtoul (tok.str, NULL, 10));
+           myline.pop_token (tok, ' ');
+           const unsigned long ahi (strtoul (tok.str, NULL, 10));
+           myline.pop_token (tok, ' ');
+           const pan::Quark group (tok);
+           if (_listener)
+              _listener->on_nntp_group (this, group, aqty, alo, ahi);
+           _group = group;
+            state = CMD_DONE;
+           break;
+        }
 
-      case TOO_MANY_CONNECTIONS:
-         state = CMD_RETRY;
-         break;
+        case SEND_ARTICLE_NOW:
+           // ready to get article; send it now
+           _socket->write_command (_post, this);
+           state = CMD_NEXT;
+           break;
 
-      default: {
-         std::string cmd (_previous_command);
-         if (cmd.size()>=2 && cmd[cmd.size()-1]=='\n' && cmd[cmd.size()-2]=='\r')
-           cmd.resize (cmd.size()-2);
-         std::string host;
-         _socket->get_host (host);
-         Log::add_err_va (_("Sending \"%s\" to %s returned an unrecognized response: \"%s\""),
-                          _previous_command.c_str(),
-                          host.c_str(),
-                          line.to_string().c_str());
-         state = CMD_FAIL;
-         break;
-      }
+        case NO_POSTING:
+        case POSTING_FAILED:
+          // if we hit a dupe, we silently continue
+          if (line.strstr("435"))
+          {
+            state = CMD_DONE;
+            break;
+          }
+          break;
+        case GROUP_NONEXISTENT:
+           state = CMD_FAIL;
+           break;
+        case XOVER_FOLLOWS:
+        case ARTICLE_FOLLOWS:
+        case NEWGROUPS_FOLLOWS:
+        case INFORMATION_FOLLOWS:
+           state = CMD_MORE;
+           _nntp_response_text = true;
+           break;
+
+        case AUTH_REJECTED:
+        case NO_GROUP_SELECTED:
+        case ERROR_CMD_NOT_UNDERSTOOD:
+        case ERROR_CMD_NOT_SUPPORTED:
+        case NO_PERMISSION:
+        case FEATURE_NOT_SUPPORTED: {
+           std::string cmd (_previous_command);
+           if (cmd.size()>=2 && cmd[cmd.size()-1]=='\n' && cmd[cmd.size()-2]=='\r')
+             cmd.resize (cmd.size()-2);
+           std::string host;
+           _socket->get_host (host);
+           Log::add_err_va (_("Sending \"%s\" to %s returned an error: %s"),
+                            cmd.c_str(),
+                            host.c_str(),
+                            line.to_string().c_str());
+           state = CMD_FAIL;
+           break;
+        }
+
+        case NO_SUCH_ARTICLE_NUMBER:
+        case NO_SUCH_ARTICLE:
+           state = CMD_FAIL;
+           break;
+
+        case TOO_MANY_CONNECTIONS:
+           state = CMD_RETRY;
+           break;
+
+        default: {
+           std::string cmd (_previous_command);
+           if (cmd.size()>=2 && cmd[cmd.size()-1]=='\n' && cmd[cmd.size()-2]=='\r')
+             cmd.resize (cmd.size()-2);
+           std::string host;
+           _socket->get_host (host);
+           Log::add_err_va (_("Sending \"%s\" to %s returned an unrecognized response: \"%s\""),
+                            _previous_command.c_str(),
+                            host.c_str(),
+                            line.to_string().c_str());
+           state = CMD_FAIL;
+           break;
+        }
+     }
    }
 
    if ((state == CMD_DONE) && !_commands.empty())
@@ -265,6 +300,7 @@ NNTP :: on_socket_error (Socket * sock UNUSED)
    fire_done_func (ERR_NETWORK, StringView());
 }
 
+/*
 namespace
 {
    void
@@ -274,6 +310,7 @@ namespace
          g_string_append (g, "\r\n");
    }
 };
+*/
 
 void
 NNTP :: write_next_command ()
@@ -302,7 +339,7 @@ NNTP :: help (Listener * l)
 }
 
 void
-NNTP :: get_group (const Quark& group)
+NNTP :: enter_group (const Quark& group)
 {
    if (group != _group)
     _commands.push_back (build_command ("GROUP %s\r\n",group.c_str()));
@@ -317,23 +354,33 @@ NNTP :: xover (const Quark   & group,
 {
    _listener = l;
 
-   get_group(group);
-
+   enter_group(group);
    _commands.push_back (build_command ("XOVER %"G_GUINT64_FORMAT"-%"G_GUINT64_FORMAT"\r\n", low, high));
-
    write_next_command ();
 }
 
+void
+NNTP :: xzver (const Quark   & group,
+               uint64_t        low,
+               uint64_t        high,
+               Listener      * l)
+{
+   _listener = l;
+
+   enter_group(group);
+   _commands.push_back (build_command ("XZVER %"G_GUINT64_FORMAT"-%"G_GUINT64_FORMAT"\r\n", low, high));
+   write_next_command ();
+}
+
+//TODO
 void
 NNTP :: xover_count_only (const Quark   & group,
                           Listener      * l)
 {
    _listener = l;
 
-   get_group(group);
-
+   enter_group(group);
    _commands.push_back (build_command ("XOVER"));
-
    write_next_command ();
 }
 
@@ -360,7 +407,7 @@ NNTP :: article (const Quark     & group,
 {
    _listener = l;
 
-   get_group(group);
+   enter_group(group);
 
    _commands.push_back (build_command ("ARTICLE %"G_GUINT64_FORMAT"\r\n", article_number));
 
@@ -374,7 +421,7 @@ NNTP :: article (const Quark     & group,
 {
    _listener = l;
 
-   get_group(group);
+   enter_group(group);
 
    _commands.push_back (build_command ("ARTICLE %s\r\n", message_id));
 
@@ -388,7 +435,7 @@ NNTP :: get_headers (const Quark     & group,
 {
   _listener = l;
 
-   get_group(group);
+   enter_group(group);
 
    _commands.push_back (build_command ("HEAD %s\r\n", message_id));
 
@@ -402,7 +449,7 @@ NNTP :: get_headers (const Quark     & group,
 {
    _listener = l;
 
-   get_group(group);
+   enter_group(group);
 
    _commands.push_back (build_command ("HEAD %"G_GUINT64_FORMAT"\r\n", article_number));
 
@@ -416,7 +463,7 @@ NNTP :: get_body (const Quark     & group,
 {
   _listener = l;
 
-   get_group(group);
+   enter_group(group);
 
    _commands.push_back (build_command ("BODY %s\r\n", message_id));
 
@@ -430,7 +477,7 @@ NNTP :: get_body (const Quark     & group,
 {
    _listener = l;
 
-   get_group(group);
+   enter_group(group);
 
    _commands.push_back (build_command ("BODY %"G_GUINT64_FORMAT"\r\n", article_number));
 
