@@ -27,6 +27,7 @@
 #include <pan/general/string-view.h>
 #include <pan/tasks/health.h>
 #include <pan/tasks/socket.h>
+#include <pan/data/data.h>
 
 namespace
 {
@@ -56,6 +57,9 @@ namespace
       NEWGROUPS_FOLLOWS          = 231,
 
       ARTICLE_POSTED_OK          = 240,
+
+      FEATURE_ENABLED            = 290,
+
       SEND_ARTICLE_NOW           = 340,
       NO_POSTING                 = 440,
       POSTING_FAILED             = 441,
@@ -72,6 +76,8 @@ namespace
       NO_PERMISSION              = 502,
       FEATURE_NOT_SUPPORTED      = 503
    };
+
+   const char* EOL = ".";
 }
 
 namespace pan
@@ -137,7 +143,8 @@ namespace pan
                                     const Quark        & group         UNUSED,
                                     unsigned long        estimated_qty UNUSED,
                                     uint64_t             low           UNUSED,
-                                    uint64_t             high          UNUSED) {}
+                                    uint64_t             high
+                                           UNUSED) {}
 
        };
 
@@ -146,14 +153,17 @@ namespace pan
         NNTP (const Quark        & server,
               const std::string  & username,
               const std::string  & password,
-              Socket         * socket):
+              ServerInfo         & info,
+              Socket             * socket):
           _server(server),
+          _server_info(info),
           _socket(socket),
           _socket_error(false),
           _listener(0),
           _username(username),
           _password(password),
-          _nntp_response_text(false)
+          _nntp_response_text(false),
+          _compression(false)
        {}
 
        virtual ~NNTP ()
@@ -162,7 +172,7 @@ namespace pan
     public:
 
       /* Internal only */
-      void get_group (const Quark& group);
+      void enter_group (const Quark& group);
       void get_headers (const Quark & group, const char * message_id, Listener  * l);
       void get_headers (const Quark & group, uint64_t article_number, Listener * l);
       void get_body (const Quark & group, const char * message_id, Listener  * l);
@@ -193,6 +203,12 @@ namespace pan
                              uint64_t             low,
                              uint64_t             high,
                              Listener           * l);
+
+      void xzver            (const Quark        & group,
+                             uint64_t             low,
+                             uint64_t             high,
+                             Listener           * l);
+
       /**
        * Executes an XOVER command: "XOVER" to count
        * the xover numbers internally
@@ -302,10 +318,14 @@ namespace pan
     public:
 
       const Quark _server;
+      ServerInfo& _server_info;
       Quark _group;
-      Quark _request_group;
       Socket * _socket;
       bool _socket_error;
+      const std::string& get_username()
+      {
+        return _username;
+      }
 
     protected:
 
@@ -326,6 +346,10 @@ namespace pan
 
       void fire_done_func (Health, const StringView& response);
 
+    public:
+      /** session flag for compression (gzip-style) (giganews etc.)*/
+      bool _compression;
+
     private: // private socket listener funcs, for socket handshake
 
       virtual bool on_socket_response (Socket*, const StringView& line);
