@@ -35,6 +35,7 @@ extern "C" {
 #include <pan/general/string-view.h>
 #include <pan/usenet-utils/mime-utils.h>
 #include <pan/general/utf8-utils.h>
+#include <pan/data-impl/rules-filter.h>
 #include "nzb.h"
 #include "task-article.h"
 #include "task-upload.h"
@@ -71,6 +72,7 @@ namespace
     quarks_t groups;
     std::string text;
     std::string path;
+    std::string paused;
     PartBatch parts;
     tasks_t tasks;
     Article a;
@@ -92,6 +94,7 @@ namespace
       groups.clear ();
       text.clear ();
       path.clear ();
+      paused.clear ();
       a.clear ();
       bytes = 0;
       number = 0;
@@ -152,6 +155,9 @@ namespace
     else if (!strcmp(element_name,"path"))
       mc.path = mc.text;
 
+    else if (!strcmp(element_name,"paused"))
+      mc.paused = mc.text;
+
     else if (!strcmp (element_name, "file"))
     {
       mc.parts.sort ();
@@ -164,7 +170,11 @@ namespace
           mc.a.xref.insert (*sit, *git, 0);
       }
       const StringView p (mc.path.empty() ? mc.fallback_path : StringView(mc.path));
-      mc.tasks.push_back (new TaskArticle (mc.ranks, mc.gs, mc.a, mc.cache, mc.read, 0, TaskArticle::DECODE, p));
+      /// TODO get action mark read from prefs (?)
+      TaskArticle* a = new TaskArticle (mc.ranks, mc.gs, mc.a, mc.cache, mc.read, TaskArticle::NO_ACTION, 0, TaskArticle::DECODE, p);
+      if (mc.paused == "1")
+        a->set_start_paused(true);
+      mc.tasks.push_back (a);
     }
 
   }
@@ -283,6 +293,8 @@ NZB :: nzb_to_xml (std::ostream             & out,
         escaped (out, path.to_view());
         out << "</path>\n";
       }
+      out << indent(depth) <<"<paused>";
+      out << (task->start_paused()) << "</paused>\n";
 
       // what groups was this crossposted in?
       quarks_t groups;
