@@ -33,8 +33,15 @@
 
 using namespace pan;
 
+Queue :: task_states_t :: task_states_t ()
+  : _decoding (NULL)
+  , _encoding (NULL)
+{
+}
+
 Queue :: Queue (ServerInfo         & server_info,
                 TaskArchive        & archive,
+                Data               & data,
                 SocketCreator      * socket_creator,
                 CertStore          & certstore,
                 Prefs              & prefs,
@@ -59,6 +66,8 @@ Queue :: Queue (ServerInfo         & server_info,
   _downloads_total(0)
 {
 
+  data.set_queue(this);
+
   tasks_t tasks;
   _archive.load_tasks (tasks);
   add_tasks (tasks, BOTTOM);
@@ -313,9 +322,8 @@ Queue :: process_task (Task * task)
   {
     debug ("working");
   }
-  else if (state._work == Task::PAUSED)
+  else if (state._work == Task::INITIAL)
   {
-    debug("paused");
     TaskUpload* t = dynamic_cast<TaskUpload*>(task);
     if (t)
       give_task_an_upload_slot(t);
@@ -326,7 +334,6 @@ Queue :: process_task (Task * task)
   }
   else if (state._work == Task::NEED_DECODER)
   {
-
     if (!_decoder_task)
       give_task_a_decoder (task);
   }
@@ -679,7 +686,7 @@ Queue :: remove_task (Task * task)
       const tasks_t tmp (_tasks.begin(), _tasks.end());
       foreach_const (tasks_t, tmp, it) {
         Task * task (*it);
-        if (task->get_state()._work == Task::PAUSED)
+        if (task->get_state()._work == Task::INITIAL)
         {
           give_task_an_upload_slot(dynamic_cast<TaskUpload*>(*it));
           break;
@@ -979,3 +986,15 @@ Queue :: get_stats (unsigned long   & queued_count,
   }
 }
 
+void
+Queue :: on_dl_limit_reached ()
+{
+  if (_prefs.get_flag("disconnect-on-dl-limit-reached", false))
+    set_online (false);
+}
+
+void
+Queue :: on_reset_xfer_bytes ()
+{
+  set_online (true);
+}
