@@ -36,6 +36,7 @@
 #include <pan/tasks/task-weak-ordering.h>
 #include <pan/tasks/socket-impl-main.h>
 #include <pan/gui/prefs.h>
+#include <pan/data/data.h>
 
 #ifdef HAVE_GNUTLS
   #include <pan/data/cert-store.h>
@@ -75,7 +76,7 @@ namespace pan
     private AdaptableSet<Task*, TaskWeakOrdering>::Listener
   {
     public:
-      Queue (ServerInfo&, TaskArchive&, SocketCreator*, CertStore&, Prefs&, WorkerPool&,
+      Queue (ServerInfo&, TaskArchive&, Data&, SocketCreator*, CertStore&, Prefs&, WorkerPool&,
              bool online, int save_delay_secs);
       virtual ~Queue ();
 
@@ -131,6 +132,7 @@ namespace pan
           Task * _decoding;
           Task * _encoding;
         public:
+          task_states_t ();
           tasks_t tasks;
           TaskState get_state (Task* task) const {
             if (_decoding && (task==_decoding)) return DECODING;
@@ -262,6 +264,12 @@ namespace pan
       virtual void on_set_items_added  (TaskSet&, TaskSet::items_t&, int index);
       virtual void on_set_item_removed (TaskSet&, Task*&, int index);
       virtual void on_set_item_moved   (TaskSet&, Task*&, int index, int old_index);
+
+    public:
+
+      virtual void on_xfer_bytes (uint64_t) {}
+      virtual void on_reset_xfer_bytes () ;
+      virtual void on_dl_limit_reached () ;
   };
 }
 
