@@ -4,7 +4,7 @@
  * Copyright (C) 2002-2006  Charles Kerr <charles@rebelbase.com>
  *
  * This file
- * Copyright (C) 2011 Heinrich Mller <henmull@src.gnome.org>
+ * Copyright (C) 2011 Heinrich Müller <henmull@src.gnome.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -305,11 +305,11 @@ namespace
   {
     GIOGnuTLSChannel *chan = (GIOGnuTLSChannel *)handle;
     g_io_channel_unref(chan->giochan);
+    // free callback struct
+    delete (mydata_t*)gnutls_session_get_ptr (chan->session);
     gnutls_deinit (chan->session);
     g_free(chan->host);
     g_free(chan);
-    // free callback struct
-    delete (mydata_t*)gnutls_session_get_ptr (chan->session);
   }
 }
 
@@ -325,10 +325,9 @@ GIOChannelSocketGnuTLS :: ~GIOChannelSocketGnuTLS ()
 
   if (_channel)
   {
-    GIOGnuTLSChannel *chan = (GIOGnuTLSChannel *)_channel;
     g_io_channel_shutdown (_channel, true, 0);
-    _gnutls_free(_channel);
     g_string_free(_channel->read_buf,true);
+    _gnutls_free(_channel);
     _channel = 0;
   }
 
@@ -340,10 +339,18 @@ GIOChannelSocketGnuTLS :: ~GIOChannelSocketGnuTLS ()
 }
 
 bool
-GIOChannelSocketGnuTLS :: open (const StringView& address, int port, std::string& setme_err)
+GIOChannelSocketGnuTLS :: open  (const StringView& address, int port, std::string& setme_err)
 {
   _host.assign (address.str, address.len);
   _channel = create_channel (address, port, setme_err);
+  if (_channel)
+  {
+#ifdef G_OS_WIN32
+      _id = g_io_channel_win32_get_fd(_channel);
+#else
+      _id = g_io_channel_unix_get_fd(_channel);
+#endif // G_OS_WIN32
+  }
   return _channel != 0;
 }
 
@@ -375,14 +382,14 @@ namespace
 
   static void set_blocking(gnutls_session_t& session, bool val)
   {
-    int fd(-1), flags;
+    int fd(-1);
     gnutls_transport_ptr_t tmp = gnutls_transport_get_ptr (session);
     fd = GPOINTER_TO_INT (tmp);
 
     if(fd)
     {
 #ifndef G_OS_WIN32
-      flags = fcntl(fd, F_GETFL);
+      int flags = fcntl(fd, F_GETFL);
       if (!val)
         flags |= O_NONBLOCK;
       else
@@ -601,7 +608,7 @@ GIOChannelSocketGnuTLS :: do_read ()
 
   bool more (true);
 
-  GIOGnuTLSChannel * chan = (GIOGnuTLSChannel*)_channel;
+//  GIOGnuTLSChannel * chan = (GIOGnuTLSChannel*)_channel;
 
   while (more && !_abort_flag)
   {
@@ -616,8 +623,8 @@ GIOChannelSocketGnuTLS :: do_read ()
 
       debug_v ("read [" << g->str << "]");
       increment_xfer_byte_count (g->len);
-      if (g_str_has_suffix (g->str, "\r\n"))
-        g_string_truncate (g, g->len-2);
+      //if (g_str_has_suffix (g->str, "\r\n"))
+      //  g_string_truncate (g, g->len-2);
       more = _listener->on_socket_response (this, StringView (g->str, g->len));
     }
     else if (status == G_IO_STATUS_AGAIN)
@@ -787,7 +794,7 @@ GIOChannelSocketGnuTLS :: gnutls_get_iochannel(GIOChannel* channel, const char*
 
 	GIOGnuTLSChannel *chan(0);
 	GIOChannel *gchan(0);
-	int err(0), fd(0);
+	int fd(0);
 
 	chan = g_new0(GIOGnuTLSChannel, 1);
 	g_return_val_if_fail(chan, 0);
@@ -820,7 +827,6 @@ GIOChannelSocketGnuTLS :: gnutls_get_iochannel(GIOChannel* channel, const char*
 	g_io_channel_init(gchan);
   gchan->read_buf = g_string_sized_new(4096*128);
 
-  int ret;
   set_blocking(session, true);
 
   if (_gnutls_handshake(gchan) == G_IO_STATUS_NORMAL)
