@@ -21,6 +21,7 @@
 #include <cassert>
 extern "C" {
   #include <glib/gi18n.h>
+  #include <stdlib.h>
 }
 #include <pan/general/debug.h>
 #include <pan/general/macros.h>
@@ -75,8 +76,19 @@ TaskGroups :: use_nntp (NNTP * nntp)
 }
 
 void
-TaskGroups :: on_nntp_line (NNTP               * nntp UNUSED,
+TaskGroups :: on_nntp_line (NNTP               * nntp,
                             const StringView   & line)
+{
+  // gzip compression
+  if (nntp->_compression)
+  {
+    stream<<line;
+  }
+  else on_nntp_line_process (nntp, line);
+}
+void
+TaskGroups :: on_nntp_line_process (NNTP               * nntp UNUSED,
+                                    const StringView   & line)
 {
   char permission ('y');
   std::string name_str;
@@ -129,7 +141,7 @@ TaskGroups :: on_nntp_line (NNTP               * nntp UNUSED,
 void
 TaskGroups :: on_nntp_done (NNTP              * nntp,
                             Health              health,
-                            const StringView  & response UNUSED)
+                            const StringView  & response)
 {
   debug ("groups task got an on_nntp_done() from " << nntp->_server);
 
@@ -137,8 +149,38 @@ TaskGroups :: on_nntp_done (NNTP              * nntp,
   {
     _state.set_need_nntp (_servername);
   }
-  else // heath is OK or FAIL
+  else // health is OK or FAIL
   {
+
+    const Quark& server(nntp->_server);
+    CompressionType comp;
+    _data.get_server_compression_type(server, comp);
+    const bool is_gzipped (comp == HEADER_COMPRESS_XFEATURE);
+
+    if (is_gzipped)
+    {
+      std::ofstream of("tmp_out");
+      of << stream.str();
+      of.close();
+      std::stringstream out,out2;
+      bool fail = !compression::inflate_zlib(&stream, &out, comp);
+      if (!fail)
+      {
+        char buf[4096];
+        while (true)
+        {
+          std::istream& str = out.getline(buf, sizeof(buf));
+          if (str.fail() || str.bad() || str.eof()) break;
+          on_nntp_line_process(nntp, buf);
+        }
+      } else
+      {
+        _state.set_completed();
+        set_finished(ERR_LOCAL);
+      }
+
+    }
+
     if (_step == LIST_NEWSGROUPS)
     {
       int i (0);
