@@ -50,16 +50,15 @@ namespace pan
          enum Work
          {
             /** Task finished successfully */
-            COMPLETED,
+            COMPLETED = 0,
             /** Task is waiting on an nntp connection */
-            NEED_NNTP,
+            NEED_NNTP = 1,
             /** Task waiting for a decoder/encoder */
-            NEED_DECODER,
-            NEED_ENCODER,
+            NEED_DECODER = 2,
+            NEED_ENCODER = 3,
             /** Task is running */
-            WORKING,
-            /** Task is paused, woken up if 'current_connections < max_connections' */
-            PAUSED
+            WORKING = 5,
+            INITIAL = 6
          };
 
          /**
@@ -84,8 +83,8 @@ namespace pan
                void set_completed () {
                    _work = COMPLETED; _servers.clear(); }
 
-               void set_paused () {
-                   _work = PAUSED; _servers.clear(); }
+               void set_initial () {
+                   _work = INITIAL; _servers.clear(); }
 
                void set_working () {
                   _work = WORKING; _servers.clear(); }
