@@ -450,7 +450,7 @@ TextMassager :: rot13_inplace (char * text)
 }
 
 std::string
-pan :: subject_to_path (const char * subjectline, bool full_subj, const std::string &seperator)
+pan :: subject_to_path (const char * subjectline, bool full_subj, const std::string &separator)
 {
   gchar *str1, *str2;
   const char *sep;
@@ -459,12 +459,12 @@ pan :: subject_to_path (const char * subjectline, bool full_subj, const std::str
   GRegexCompileFlags cf0((GRegexCompileFlags)0);
   GRegexMatchFlags mf0((GRegexMatchFlags)0);
 
-  if (seperator.length() != 1)
+  if (separator.length() != 1)
     sep = "-";
-  else switch (seperator[0]) {
+  else switch (separator[0]) {
     case ' ':
     case '-':
-    case '_': sep = seperator.c_str(); break;
+    case '_': sep = separator.c_str(); break;
     default : sep = "-"; break;
   }
 
@@ -568,7 +568,7 @@ pan :: expand_attachment_headers(const Quark& path, const Article& article)
   if (path.empty()) return std::string("");
   std::string val(path.c_str());
   std::string::size_type pos;
-  std::string author_str (article.author.c_str());
+  std::string author_str (article.author.empty() ? "" : article.author);
   std::pair<std::string,std::string> author (get_email_address(author_str));
   std::string author_name (author.first);
   std::string author_email (author.second);
